@@ -17,7 +17,8 @@
  */
 
 #include <Python.h>
-//#define NO_IMPORT_PYGOBJECT 1
+#define NO_IMPORT_PYGOBJECT
+#define NO_IMPORT_PYGTK
 #include <pygobject.h>
 #include <pygtk/pygtk.h>
 #include "gcompris/gcompris.h"
@@ -135,17 +136,115 @@ get_pythonboards_list()
   return pythonboards_list;
 }
 
+/* This loops over all the boards and for the python one
+ * checks if they have a config method defined. If so
+ * they are put in a list.
+ */
+static void
+init_config_boards()
+{
+  static gboolean called_once = FALSE;
+  GList *python_boards;
+  GList *list;
+  PyObject* globals;
+  static char *python_args[]={ "" };
+  static char* python_prog_name="gcompris";
+  char* boardclass;
+  char* board_file_name;
+  PyObject* main_module;
+  char* boarddir;
+  GcomprisProperties *properties = gc_prop_get();
+  PyObject* module_dict;
+  PyObject* py_boardclass;
+
+  if (called_once)
+    return;
+
+  called_once = TRUE;
+
+  if(!Py_IsInitialized()){
+    /* Initialize the python interpreter */
+    Py_SetProgramName(python_prog_name);
+    Py_Initialize();
+
+    PySys_SetArgv(1, python_args);
+
+    init_pygobject();
+
+    main_module = PyImport_AddModule("__main__");
+    globals = PyModule_GetDict(main_module);
+
+    if(globals==NULL){
+      g_print("Cannot get info from the python interpreter. Seems there is a problem with this one.\n");
+      return;
+    }
+
+    /* Add the python plugins dir to the python's search path */
+    boarddir = g_strdup_printf("import sys; sys.path.append('%s')",
+			       properties->package_python_plugin_dir );
+
+    PyRun_SimpleString(boarddir);
+    g_free(boarddir);
+
+    /* Load the gcompris modules */
+    python_gcompris_module_init();
+  }
+  else {
+    main_module = PyImport_AddModule("__main__"); /* Borrowed reference */
+    globals = PyModule_GetDict(main_module); /* Borrowed reference */
+  }
+
+
+  /* Get the list of python boards */
+  python_boards = get_pythonboards_list();
+
+  /* Search in the list each one with a config entry */
+  for(list = python_boards; list != NULL; list = list->next) {
+    GcomprisBoard *board = (GcomprisBoard *) list->data;
+
+    /* Python is now initialized we create some usefull variables */
+    board_file_name = strchr(board->type, ':')+1;
+    boardclass = g_strdup_printf("Gcompris_%s", board_file_name);
+
+    /* Test if board come with --python_plugin_dir option */
+
+    g_message("board_dir: '%s' python_plugin_dir '%s' file_name '%s'",
+	      board->board_dir,
+	      properties->package_python_plugin_dir,
+	      board_file_name);
+
+    /* Insert the board module into the python's interpreter */
+    python_board_module = PyImport_ImportModuleEx(board_file_name,
+						  globals,
+						  globals,
+						  NULL);
+
+    if(python_board_module!=NULL){
+      /* Get the module dictionnary */
+      module_dict = PyModule_GetDict(python_board_module);
+
+      /* Get the python board class */
+      py_boardclass = PyDict_GetItemString(module_dict, boardclass);
+
+      if (PyObject_HasAttrString( py_boardclass, "config_start")) {
+	config_boards = g_list_append(config_boards, board);
+	g_message("The board '%s' has a configuration entry",
+		  board_file_name);
+      }
+    }
+    g_free(boardclass);
+  }
+  g_list_free(python_boards);
+
+  /* Finalize the python interpreter */
+  Py_Finalize();
+}
+
 static void
 pythonboard_init (GcomprisBoard *agcomprisBoard){
   PyObject* main_module;
   PyObject* globals;
   gchar* execstr;
-  gchar* userplugindir;
-
-  char* board_file_name;
-  char* boardclass;
-  PyObject* module_dict;
-  PyObject* py_boardclass;
 
   GcomprisProperties *properties = gc_prop_get();
 
@@ -168,16 +267,7 @@ pythonboard_init (GcomprisBoard *agcomprisBoard){
     pythonboard_is_ready = FALSE;
   } else {
     /* Add the python plugins dir to the python's search path */
-#ifndef DISABLE_USER_PLUGIN_DIR
-    userplugindir = g_strconcat(g_get_home_dir(), properties->config_dir,
-				"/Plugins/",
-				NULL);
-    execstr = g_strdup_printf("import sys; sys.path.append('%s/python'); sys.path.append('%s')",
-			      userplugindir, properties->package_python_plugin_dir);
-    g_free(userplugindir);
-#else
     execstr = g_strdup_printf("import sys; sys.path.append('%s')",properties->package_python_plugin_dir );
-#endif
 
     g_message("Executing %s\n", execstr);
     if(PyRun_SimpleString(execstr)!=0){
@@ -204,54 +294,7 @@ pythonboard_init (GcomprisBoard *agcomprisBoard){
 	if(PyRun_SimpleString(execstr)!=0){
 	  pythonboard_is_ready = FALSE;
 	  g_warning("! Python disabled: Cannot import gcompris modules\n");
-	} else {
-	  GList *python_boards;
-	  GList *list;
-
-	  /* Get the list of python boards */
-	  python_boards = get_pythonboards_list();
-
-	  /* Search in the list each one with a config entry */
-	  for(list = python_boards; list != NULL; list = list->next) {
-	    GcomprisBoard *board = (GcomprisBoard *) list->data;
-
-	    /* Python is now initialized we create some usefull variables */
-	    board_file_name = strchr(board->type, ':')+1;
-	    boardclass = g_strdup_printf("Gcompris_%s", board_file_name);
-
-	    /* Test if board come with --python_plugin_dir option */
-
-	    g_message("board_dir: '%s' python_plugin_dir '%s' file_name '%s'",
-		      board->board_dir,
-		      properties->package_python_plugin_dir,
-		      board_file_name);
-
-	    /* Insert the board module into the python's interpreter */
-	    python_board_module = PyImport_ImportModuleEx(board_file_name,
-							  globals,
-							  globals,
-							  NULL);
-
-	    if(python_board_module!=NULL){
-	      /* Get the module dictionnary */
-	      module_dict = PyModule_GetDict(python_board_module);
-
-	      /* Get the python board class */
-	      py_boardclass = PyDict_GetItemString(module_dict, boardclass);
-
-	      if (PyObject_HasAttrString( py_boardclass, "config_start")) {
-		config_boards = g_list_append(config_boards, board);
-		g_message("The board '%s' has a configuration entry",
-			  board_file_name);
-	      }
-	    }
-
-	    g_free(boardclass);
-	  }
-
-	  g_list_free(python_boards);
 	}
-      }
     }
     g_free(execstr);
 
@@ -260,6 +303,7 @@ pythonboard_init (GcomprisBoard *agcomprisBoard){
   /* Finalize the python interpreter */
   Py_Finalize();
 
+  }
 }
 
 /*
@@ -284,7 +328,6 @@ pythonboard_start (GcomprisBoard *agcomprisBoard){
   char* boarddir;
   char* boardclass;
   char* board_file_name;
-  gchar *userplugindir;
 
   GcomprisProperties	*properties = gc_prop_get();
 
@@ -308,14 +351,7 @@ pythonboard_start (GcomprisBoard *agcomprisBoard){
     }
 
     /* Add the python plugins dir to the python's search path */
-#ifndef DISABLE_USER_PLUGIN_DIR
-    userplugindir = g_strconcat(g_get_home_dir(), "/.gcompris/Plugins/", NULL);
-    boarddir = g_strdup_printf("import sys; sys.path.append('%s/python'); sys.path.append('%s')",
-			       userplugindir,
-			       properties->package_python_plugin_dir);
-#else
     boarddir = g_strdup_printf("import sys; sys.path.append('%s')",properties->package_python_plugin_dir );
-#endif
 
     PyRun_SimpleString(boarddir);
     g_free(boarddir);
@@ -330,10 +366,6 @@ pythonboard_start (GcomprisBoard *agcomprisBoard){
     }
 
 
-#ifndef DISABLE_USER_PLUGIN_DIR
-    g_free(userplugindir);
-#endif
-
     /* Load the gcompris modules */
     python_gcompris_module_init();
 
@@ -431,6 +463,7 @@ static gboolean pythonboard_is_our_board (GcomprisBoard *gcomprisBoard){
 
       if (g_ascii_strncasecmp(gcomprisBoard->type, "python", 6)==0) {
 
+	init_config_boards();
 	/* Set the plugin entry */
 	if (g_list_find (config_boards, gcomprisBoard)){
 	  gcomprisBoard->plugin = &menu_bp;
@@ -552,7 +585,6 @@ pythongc_board_config_start (GcomprisBoard *agcomprisBoard,
   char* board_file_name;
   PyObject* main_module;
   char* boarddir;
-  gchar *userplugindir;
 
   g_assert (agcomprisBoard != NULL);
 
@@ -575,24 +607,11 @@ pythongc_board_config_start (GcomprisBoard *agcomprisBoard,
       gcomprisBoard_config = agcomprisBoard;
     }
 
-    /* Add the python plugins dir to the python's search path */
-#ifndef DISABLE_USER_PLUGIN_DIR
-    userplugindir = g_strconcat(g_get_home_dir(), "/.gcompris/Plugins/", NULL);
-    boarddir = g_strdup_printf("import sys; sys.path.append('%s/python'); sys.path.append('%s'); sys.path.append('%s')",
-			       userplugindir,
-			       properties->package_python_plugin_dir,
-			       gcomprisBoard_config->board_dir);
-#else
     boarddir = g_strdup_printf("import sys; sys.path.append('%s')", properties->package_python_plugin_dir );
-#endif
 
     PyRun_SimpleString(boarddir);
     g_free(boarddir);
 
-#ifndef DISABLE_USER_PLUGIN_DIR
-    g_free(userplugindir);
-#endif
-
     /* Load the gcompris modules */
     python_gcompris_module_init();
 
