@@ -32,6 +32,14 @@
 # define WIN32
 #endif
 
+#ifndef SIGPIPE
+#define SIGPIPE 13
+#endif
+
+#ifndef SIGTRAP
+#define SIGTRAP 5
+#endif
+
 #define SOUNDLISTFILE PACKAGE
 
 static GcomprisBoard *gcomprisBoard = NULL;
@@ -211,8 +219,8 @@ static void pause_board (gboolean pause)
 
 void gnuchess_died(int signum)
 {
-  gnuchess_pid = 0;
-  gc_dialog(_("Error: The external program gnuchess died unexpectedly"), gc_board_stop);
+  gc_dialog(_("Error: The external program gnuchess died unexpectedly"),
+	    gc_board_stop);
 }
 
 /*
@@ -220,7 +228,6 @@ void gnuchess_died(int signum)
 static void start_board (GcomprisBoard *agcomprisBoard)
 {
 
-  gnuchess_pid = 0;
   gchar **gnuchess_pathptr = gnuchess_path;
   gchar *gnuchess_bin = NULL;
 
@@ -243,6 +250,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 	break;
 
       gnuchess_pathptr++;
+      g_free(gnuchess_bin);
     } while(*gnuchess_pathptr != NULL);
 
   if(*gnuchess_pathptr == NULL)
@@ -1049,9 +1057,6 @@ static void
 engine_local_destroy (GPid gnuchess_pid)
 {
 
-  if(!gnuchess_pid)
-    return;
-
   g_warning("engine_local_destroy () \n");
   write_child (write_chan, "quit\n");
 
@@ -1064,8 +1069,7 @@ engine_local_destroy (GPid gnuchess_pid)
   g_io_channel_close (write_chan);
   g_io_channel_unref (write_chan);
 
-  if(gnuchess_pid)
-    g_spawn_close_pid(gnuchess_pid);
+  g_spawn_close_pid(gnuchess_pid);
 }
 
 /** We got data back from gnuchess, we parse them here
@@ -1077,17 +1081,16 @@ engine_local_cb (GIOChannel *source,
 		 gpointer data)
 {
   gchar buf[1000];
-  char *b=buf;
-  GError *err = NULL;
-  char *p,*q;
+  gchar *pbuf = buf;
   gsize len = 0;
-  GIOStatus status = G_IO_STATUS_NORMAL;
-
   g_warning("engine_local_cb");
 
+#ifndef WIN32
+  GError *err = NULL;
+  GIOStatus status = G_IO_STATUS_NORMAL;
   status = g_io_channel_read_chars(source,
 				   buf,
-				   1000,
+				   sizeof(buf)-1,
 				   &len,
 				   &err);
 
@@ -1107,31 +1110,45 @@ engine_local_cb (GIOChannel *source,
       /* FIXME: Not sure what to do */
       return FALSE;
     }
+#else
+  GIOError  gioError;
+  gioError = g_io_channel_read  (source,
+				 buf,
+				 sizeof(buf)-1,
+				 &len);
+  g_warning("g_io_channel_read_line len=%d", (int)len);
+  if(gioError != G_IO_ERROR_NONE)
+    {
+      g_warning("g_io_channel_read error=%d",
+		gioError);
+      /* FIXME: Not sure what to do */
+      return FALSE;
+    }
+#endif
+
+  buf[len] = '\0';
 
   g_warning("engine_local_cb read=%s\n", buf);
 
-  if (len > 0) {
-    b[len] = 0;
-    b += len;
-  }
-
   while (1) {
-    char tmp;
+    char *next;
+    char *p;
 
-    q = strchr (buf,'\n');
-    if (q == NULL) break;
-    tmp = *(q+1);
-    *(q+1) = '\0';
+    next = strchr (pbuf,'\n');
+    if (next == NULL) { g_warning("BREAK"); break;}
+    *next='\0';
+    next++;
 
-    *q='\0';
-    *(q+1) = tmp;
-
-    g_warning("engine_local_cb read=%s\n", buf);
+    g_warning("engine_local_cb line=%s\n", pbuf);
 
     /* parse for  NUMBER ... MOVE */
-    if (isdigit (*buf))
+    if (isdigit (*pbuf))
       {
-	if ((p = strstr (buf, "...")))
+	if ((p = strstr (pbuf, "...")) && (strlen(p) == 4) )
+	  {
+	    return TRUE;
+	  }
+	else if ((p = strstr (pbuf, "...")))
 	  {
 	    Square from, to;
 
@@ -1143,19 +1160,19 @@ engine_local_cb (GIOChannel *source,
 	    position_move (position, from, to);
 	    move_piece_to(from , to);
 	  }
-	else if ((p = strstr (buf, " ")))
+	else if ((p = strstr (pbuf, " ")))
 	  {
-	    /* It's a legal move case */
-	    g_warning("Legal move to %s\n", p+1);
+	    /* It's an unkown response */
+	    g_warning("Unkown response %s\n", p+1);
 	  }
       }
 
     /* parse for move MOVE */
-    if (!strncmp ("My move is : ",buf,13))
+    if (!strncmp ("My move is : ",pbuf,13))
       {
 	Square from, to;
 
-	p = strstr (buf, ":");
+	p = strstr (pbuf, ":");
 	g_warning("computer moves to %s\n", p+1);
 
 	if (san_to_move (position, p+1, &from, &to))
@@ -1166,28 +1183,28 @@ engine_local_cb (GIOChannel *source,
       }
 
     /* parse for illegal move */
-    if (!strncmp ("Illegal move",buf,12))
+    if (!strncmp ("Illegal move",pbuf,12))
       {
-	g_warning("Illegal move to %s : SHOULD NOT HAPPEN", buf+31);
+	g_warning("Illegal move to %s : SHOULD NOT HAPPEN", pbuf+31);
       }
 
-    if (!strncmp ("0-1",buf,3))
+    if (!strncmp ("0-1",pbuf,3))
       {
 	display_info(_("Black mates"));
       }
 
-    if (!strncmp ("1-0",buf,3))
+    if (!strncmp ("1-0",pbuf,3))
       {
 	display_info(_("White mates"));
       }
 
-    if (!strncmp ("1/2-1/2",buf,7))
+    if (!strncmp ("1/2-1/2",pbuf,7))
       {
 	display_info(_("Drawn game"));
       }
 
     /* parse for feature */
-    if (!strncmp ("feature",buf,7))
+    if (!strncmp ("feature",pbuf,7))
       {
 	write_child(write_chan, "accepted setboard\n");
 	write_child(write_chan, "accepted analyze\n");
@@ -1197,9 +1214,8 @@ engine_local_cb (GIOChannel *source,
 	write_child(write_chan, "accepted myname\n");
 	write_child(write_chan, "accepted done\n");
       }
-
-    memmove (buf, q+1, sizeof(buf) - ( q + 1 - buf));
-    b -= (q + 1 - buf);
+    // Process next line
+    pbuf = next;
   }
 
   return TRUE;
@@ -1210,8 +1226,8 @@ engine_local_err_cb (GIOChannel *source,
 		     GIOCondition condition,
 		     gpointer data)
 {
-  gnuchess_pid = 0;
-  gc_dialog(_("Error: The external program gnuchess died unexpectingly"), gc_board_stop);
+  gc_dialog(_("Error: The external program gnuchess died unexpectingly"),
+	    gc_board_stop);
   return FALSE;
 }
 
@@ -1246,7 +1262,7 @@ start_child (char *cmd,
 
   }
 
-  g_warning("gnuchess subprocess is started");
+  g_warning("gnuchess subprocess is started (%d)", (int)*Child_Process);
 
   *read_chan = g_io_channel_unix_new (Child_Out);
   *write_chan = g_io_channel_unix_new (Child_In);
