@@ -27,8 +27,11 @@ static struct BoardPluginData *bp_data;
 
 static gboolean	 get_board_playing(void);
 
-#ifdef STATIC_MODULE
+#ifdef ACTIVATION_CODE
 int gc_activation_check(char *code);
+#endif
+
+#ifdef STATIC_MODULE
 extern BoardPlugin * get_advanced_colors_bplugin_info();
 extern BoardPlugin * get_algebra_bplugin_info();
 extern BoardPlugin * get_algebra_guesscount_bplugin_info();
@@ -57,6 +60,7 @@ extern BoardPlugin * get_menu_bplugin_info();
 extern BoardPlugin * get_missingletter_bplugin_info();
 extern BoardPlugin * get_money_bplugin_info();
 extern BoardPlugin * get_paratrooper_bplugin_info();
+extern BoardPlugin * get_photohunter_bplugin_info();
 extern BoardPlugin * get_planegame_bplugin_info();
 extern BoardPlugin * get_railroad_bplugin_info();
 extern BoardPlugin * get_read_colors_bplugin_info();
@@ -113,6 +117,7 @@ void gc_board_init(void)
   static_boards_demo[i++] = get_menu_bplugin_info();
   static_boards_demo[i++] = get_money_bplugin_info();
   static_boards_demo[i++] = get_reading_bplugin_info();
+  static_boards_demo[i++] = get_photohunter_bplugin_info();
   static_boards_demo[i++] = get_python_bplugin_info();
   static_boards_demo[i++] = get_scale_bplugin_info();
   static_boards_demo[i++] = get_submarine_bplugin_info();
@@ -152,6 +157,7 @@ void gc_board_init(void)
   static_boards[i++] = get_missingletter_bplugin_info();
   static_boards[i++] = get_money_bplugin_info();
   static_boards[i++] = get_paratrooper_bplugin_info();
+  static_boards[i++] = get_photohunter_bplugin_info();
   static_boards[i++] = get_planegame_bplugin_info();
   static_boards[i++] = get_python_bplugin_info();
   static_boards[i++] = get_railroad_bplugin_info();
@@ -230,13 +236,10 @@ gc_board_check_file(GcomprisBoard *gcomprisBoard)
     return TRUE;
   }
 
-  if(properties->administration)
-    key_is_valid = 1;
-  else
-    key_is_valid = gc_activation_check(properties->key);
+  key_is_valid = gc_activation_check(properties->key);
 
   i = 0;
-  if(key_is_valid == 1)
+  if(key_is_valid >= 1)
     {
       while(static_boards[i++] != NULL) {
 
@@ -248,8 +251,6 @@ gc_board_check_file(GcomprisBoard *gcomprisBoard)
 	  g_message("We found the correct plugin for board %s (type=%s)\n",
 		    gcomprisBoard->name, gcomprisBoard->type);
 
-	  gcomprisBoard->plugin = bp;
-
 	  return TRUE;
 	}
       }
@@ -279,8 +280,6 @@ gc_board_check_file(GcomprisBoard *gcomprisBoard)
 	  g_warning("We found the correct plugin for board %s (type=%s)\n",
 		  gcomprisBoard->name, gcomprisBoard->type);
 
-	  gcomprisBoard->plugin = bp;
-
 	  return TRUE;
 	}
       }
@@ -306,6 +305,17 @@ gc_board_check_file(GcomprisBoard *gcomprisBoard)
 
   g_assert(gcomprisBoard!=NULL);
 
+#ifdef ACTIVATION_CODE
+  if ( !gcomprisBoard->demo && gc_activation_check(properties->key) <= 0 )
+    return FALSE;
+#endif
+
+#if defined WIN32 || defined MAC_INTEGRATION
+  /* Some activities are not relevant on some platform */
+  if (strcmp("tuxpaint", gcomprisBoard->name) == 0)
+    return FALSE;
+#endif
+
   /* Check Already loaded */
   if(gcomprisBoard->plugin!=NULL) {
     return TRUE;
