@@ -173,19 +173,8 @@ gc_board_config_window_display(gchar *label, GcomprisConfCallback callback)
 
 
   /* parameters */
-#ifdef XF86_VIDMODE
-  if (gc_prop_get()->fullscreen &&
-      !gc_prop_get()->noxf86vm)
-    {
-      memset(&last_configure_event, 0, sizeof(GdkEventConfigure));
-      gtk_widget_add_events(GTK_WIDGET(config->conf_window), GDK_STRUCTURE_MASK);
-      gtk_signal_connect (GTK_OBJECT (config->conf_window), "configure_event",
-        GTK_SIGNAL_FUNC (_conf_window_configured), config);
-    }
-  else
-#endif
-      gtk_window_set_position (config->conf_window,
-				   GTK_WIN_POS_CENTER_ALWAYS);
+  gtk_window_set_position (config->conf_window,
+			   GTK_WIN_POS_CENTER_ALWAYS);
 
   gtk_widget_show(GTK_WIDGET(config->conf_window));
 
