@@ -29,7 +29,6 @@
 
 static GooCanvasItem	*rootitem		= NULL;
 static GooCanvasItem	*item_locale_text	= NULL;
-static GooCanvasItem	*item_locale_flag	= NULL;
 static GooCanvasItem	*item_bad_flag		= NULL;
 static GooCanvasItem	*item_timer_text	= NULL;
 static GooCanvasItem	*item_skin_text		= NULL;
@@ -60,6 +59,7 @@ static gchar *linguas[] = {
   "af_ZA.UTF-8", 	N_("Afrikaans"),
   "am_ET.UTF-8", 	N_("Amharic"),
   "ar_AE.UTF-8", 	N_("Arabic"),
+  "ast_ES.UTF-8", 	N_("Asturian"),
   "az_AZ.UTF-8", 	N_("Turkish (Azerbaijan)"),
   "bg_BG.UTF-8",	N_("Bulgarian"),
   "br_FR.UTF-8",	N_("Breton"),
@@ -131,9 +131,8 @@ static gchar *timername[] = {
   N_("Fast timer")
 };
 
-static gchar *filtername[] = {
-  N_("<i>Use Gcompris administration module\nto filter boards</i>")
-};
+static gchar *filtername =
+  N_("Use Gcompris administration module to filter boards");
 
 static void set_locale_flag(gchar *locale);
 static gchar *get_next_locale(gchar *locale);
@@ -207,9 +206,6 @@ gc_config_start ()
 
   display_previous_next(x_start, y_start, "locale_previous", "locale_next");
 
-  item_locale_flag = goo_canvas_svg_new (rootitem,
-					 rsvg_handle_new(),
-					 NULL);
   y_flag_start = y_start - pixmap_width/2;
 
   /* Display a bad icon if this locale is not available */
@@ -316,6 +312,31 @@ gc_config_start ()
 		       "fill-color-rgba", gc_skin_color_content,
 		       NULL);
 
+  // Zoom
+  y_start += Y_GAP;
+
+  item = goo_canvas_svg_new (rootitem,
+			     gc_skin_rsvg_get(),
+			     "svg-id", (properties->zoom ? pixmap_checked : pixmap_unchecked),
+			     "autocrop", TRUE,
+			     NULL);
+  SET_ITEM_LOCATION(item, x_start, y_start - pixmap_width/2);
+
+  g_signal_connect(item, "button_press_event",
+		   (GtkSignalFunc) item_event_ok,
+		   "zoom");
+  gc_item_focus_init(item, NULL);
+
+  goo_canvas_text_new (rootitem,
+		       _("Zoom"),
+		       (gdouble) x_text_start,
+		       (gdouble) y_start,
+		       -1,
+		       GTK_ANCHOR_WEST,
+		       "font", gc_skin_font_subtitle,
+		       "fill-color-rgba", gc_skin_color_content,
+		       NULL);
+
   // Timer
   y_start += Y_GAP;
 
@@ -397,21 +418,20 @@ gc_config_start ()
   // Difficulty Filter
   y_start += Y_GAP;
 
-  //  display_previous_next(x_start, y_start, "filter_style_previous", "filter_style_next");
-
   stars_group_x = x_start + 45;
   stars_group_y = y_start - 25;
-
+  gchar *text = g_strdup_printf("<i>%s</i>", gettext(filtername));
   item_filter_text = goo_canvas_text_new (rootitem,
-					  gettext(filtername[0]),
+					  text,
 					  x_text_start,
 					  y_start,
-					  -1,
+					  400,
 					  GTK_ANCHOR_WEST,
 					  "use-markup", TRUE,
 					  "font", gc_skin_font_subtitle,
 					  "fill-color-rgba", gc_skin_color_content,
 					  NULL);
+  g_free(text);
 
 
   // OK
@@ -516,7 +536,6 @@ display_previous_next(guint x_start, guint y_start,
 static void
 set_locale_flag(gchar *locale)
 {
-  gchar *filename;
 
   if(locale == NULL)
     return;
@@ -527,48 +546,6 @@ set_locale_flag(gchar *locale)
     g_message("gc_locale_get_user_default = %s\n", locale);
   }
 
-  /* First try to find a flag for the long locale name */
-  filename = gc_file_find_absolute("flags/%.5s.svgz", locale);
-
-  /* Not found, Try now with the short locale name */
-  if(!filename) {
-    filename = gc_file_find_absolute("flags/%.2s.svgz", locale);
-  }
-
-  if(filename)
-    {
-      RsvgHandle *svg_handle;
-      RsvgDimensionData dimension;
-
-      svg_handle = gc_rsvg_load(filename);
-      rsvg_handle_get_dimensions(svg_handle, &dimension);
-
-      /* Calc the ratio to display it */
-      double xratio =  210.0  / dimension.width;
-      double yratio =  160.0  / dimension.height;
-      xratio = MIN(xratio, yratio);
-      goo_canvas_item_set_transform(item_locale_flag, NULL);
-      goo_canvas_item_scale(item_locale_flag,
-			    xratio, xratio);
-      goo_canvas_item_translate(item_locale_flag,
-				(x_flag_start + 260) / xratio,
-				(y_flag_start + 40) / xratio);
-
-      g_object_set (item_locale_flag,
-		    "svg-handle", svg_handle,
-		    NULL);
-
-      g_object_unref(svg_handle);
-      g_free(filename);
-    }
-  else
-    {
-      /* No flags */
-      g_object_set (item_locale_flag,
-		    "svg-handle", rsvg_handle_new(),
-		    NULL);
-    }
-
   /* Check wether or not the locale is available */
 #ifdef WIN32
   /* On win32, it's always available, do not try to check */
@@ -597,7 +574,6 @@ static gchar *
 get_next_locale(gchar *locale)
 {
   guint i = 0;
-
   while(linguas[i] != NULL)
     {
       if(!strcmp(locale, linguas[i]))
@@ -704,8 +680,6 @@ item_event_ok(GooCanvasItem *item,
   else if(!strcmp((char *)data, "music"))
     {
       properties->music = (properties->music ? 0 : 1);
-      if (properties->music)
-	gc_sound_init();
       g_object_set (item,
 		    "svg-id", (properties->music ? pixmap_checked : pixmap_unchecked),
 		    NULL);
@@ -715,6 +689,7 @@ item_event_ok(GooCanvasItem *item,
 	}
       else
 	{
+	  gc_sound_init();
 	  gc_sound_bg_reopen();
 	}
       gc_item_focus_init(item, NULL);
@@ -729,6 +704,15 @@ item_event_ok(GooCanvasItem *item,
 		    NULL);
       gc_item_focus_init(item, NULL);
     }
+  else if(!strcmp((char *)data, "zoom"))
+    {
+      properties->zoom = (properties->zoom ? 0 : 1);
+      gc_update_canvas_zoom();
+      g_object_set (item,
+		    "svg-id", (properties->zoom ? pixmap_checked : pixmap_unchecked),
+		    NULL);
+      gc_item_focus_init(item, NULL);
+    }
   else if(!strcmp((char *)data, "locale_previous"))
     {
       current_locale = get_previous_locale(current_locale);
