@@ -31,6 +31,10 @@
 
 #include "gcompris.h"
 
+#ifdef WIN32
+#define realpath(N,R) _fullpath((R),(N),_MAX_PATH)
+#endif
+
 extern GooCanvas *canvas;
 
 typedef void (*sighandler_t)(int);
@@ -650,9 +654,10 @@ gc_file_find_absolute(const gchar *format, ...)
 
  FOUND:
   g_free(filename);
-  char *abs_name = realpath(absolute_filename, NULL);
-  g_free(absolute_filename);
-  return abs_name;
+  //  printf("absolute_filename=%s\n", absolute_filename);
+  //  char *abs_name = realpath(absolute_filename, NULL);
+  //g_free(absolute_filename);
+  return absolute_filename;
 }
 
 gchar*
