@@ -83,6 +83,9 @@ struct _GcomprisBoard
 
   /* IM_context control */
   gboolean             disable_im_context;
+
+  /* This activity is a demo one */
+  gboolean	       demo;
 };
 
 
