@@ -24,10 +24,21 @@
 #include <time.h>
 #include <string.h>
 
+#ifdef WIN32
+// WIN32
+#elif MAC_INTEGRATION
+// MACOSX
+#else
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
 #include <gdk/gdkx.h>
+#endif
+
+// Include Mac OS X menu synchronization on native OSX build
+#ifdef  MAC_INTEGRATION
+#include "ige-mac-menu.h"
+#endif
 
 #include <glib/gstdio.h>
 
@@ -35,15 +46,12 @@
 #include "gc_core.h"
 #include "gcompris_config.h"
 #include "about.h"
+#include "bar.h"
+#include "status.h"
 #include <locale.h>
 
 #include "binreloc.h"
 
-/* for NSBUNDLE */
-#ifdef NSBUNDLE
-#include "gcompris-nsbundle.h"
-#endif
-
 /* get the default database name */
 #define DEFAULT_DATABASE "gcompris_sqlite.db"
 
@@ -54,20 +62,14 @@ static double zoom_factor = 1.0;
 #define GC_LOCK_LIMIT 30 /* seconds */
 
 static GtkWidget *window;
+static GtkWidget *workspace;
+static GtkWidget *alignment;
 static GtkWidget *canvas;
-static GtkWidget *fixed;
-static GtkWidget *drawing_area;
 gchar * exec_prefix = NULL;
 
 //static gint pause_board_cb (GtkWidget *widget, gpointer data);
 static void quit_cb (GtkWidget *widget, gpointer data);
 static void map_cb  (GtkWidget *widget, gpointer data);
-static gint _gc_configure_event_callback (GtkWidget   *widget,
-					  GdkEventConfigure *event,
-					  gpointer     client_data);
-static gboolean _expose_background_callback (GtkWidget *widget,
-					     GdkEventExpose *event,
-					     gpointer data);
 static gboolean _realize_callback (GtkWidget *widget, GdkEventExpose *event,
 				   gpointer data);
 static gint board_widget_key_press_callback (GtkWidget   *widget,
@@ -79,14 +81,14 @@ static void single_instance_release();
 /*
  * For the Activation dialog
  */
-#ifdef STATIC_MODULE
+#ifdef ACTIVATION_CODE
 int gc_activation_check(const char *code);
 static void activation_enter_callback(GtkWidget *widget,
 				      GtkWidget *entry );
 static void activation_done();
 static int display_activation_dialog();
 static GooCanvasItem *activation_item;
-static GtkEntry *widget_activation_entry;
+static GtkWidget *widget_activation_entry;
 #else
 #define display_activation_dialog() FALSE
 #endif
@@ -95,6 +97,8 @@ static GtkEntry *widget_activation_entry;
 static GcomprisProperties *properties = NULL;
 static gboolean		   is_mapped = FALSE;
 static gboolean		   fullscreen;
+static gboolean		   mute;
+static guint		   gc_cursor_current;
 
 /****************************************************************************/
 /* Some constants.  */
@@ -142,6 +146,10 @@ static gchar *popt_cache_dir       = NULL;
 static gchar *popt_drag_mode       = NULL;
 static gchar *sugarBundleId        = NULL;
 static gchar *sugarActivityId      = NULL;
+static gint popt_sugar_look        = FALSE;
+static gint popt_no_zoom           = FALSE;
+static gdouble popt_timing_base    = 1.0;
+static gdouble popt_timing_mult    = 1.0;
 
 static GOptionEntry options[] = {
   {"fullscreen", 'f', 0, G_OPTION_ARG_NONE, &popt_fullscreen,
@@ -246,6 +254,18 @@ static GOptionEntry options[] = {
   {"sugarActivityId", '\0', 0, G_OPTION_ARG_STRING, &sugarActivityId,
    "Sugar Activity Id", NULL},
 
+  {"sugar",'\0', 0, G_OPTION_ARG_NONE, &popt_sugar_look,
+   ("Use Sugar DE look&feel"), NULL},
+
+  {"no-zoom",'\0', 0, G_OPTION_ARG_NONE, &popt_no_zoom,
+   ("Disable maximization zoom"), NULL},
+
+  {"timing-base",'\0', 0, G_OPTION_ARG_DOUBLE, &popt_timing_base,
+   ("Increase activiites' timeout delays; useful values > 1.0; 1.0 to not change hardcoded value"), NULL},
+
+  {"timing-mult",'\0', 0, G_OPTION_ARG_DOUBLE, &popt_timing_mult,
+   ("How activiites' timeout delays are growing for several actors; useful values < 1.0; 1.0 to not change hardcoded value"), NULL},
+
   { NULL }
 };
 
@@ -268,30 +288,27 @@ double gc_zoom_factor_get()
 }
 
 static gint
-_gc_configure_event_callback (GtkWidget   *widget,
-			      GdkEventConfigure *event,
+_gc_size_allocate_event_callback (GtkWidget   *widget,
+			      GtkAllocation *allocation,
 			      gpointer     client_data)
 {
   double xratio, yratio;
-  gint screen_height, screen_width;
+  double canvas_width, canvas_height;
 
-  gdk_drawable_get_size(GDK_DRAWABLE (window->window),
-			&screen_width,
-			&screen_height);
-
-  yratio=screen_height/(float)(BOARDHEIGHT);
-  xratio=screen_width/(float)BOARDWIDTH;
+  yratio=allocation->height/(float)(BOARDHEIGHT);
+  xratio=allocation->width/(float)BOARDWIDTH;
   zoom_factor = MIN(xratio, yratio);
   g_message("The screen_width=%f screen_height=%f ratio=%f\n",
-	    (double)screen_width, (double)screen_height, zoom_factor);
+	    (double)allocation->width, (double)allocation->height, zoom_factor);
 
-  gtk_widget_set_usize (canvas, BOARDWIDTH*zoom_factor, BOARDHEIGHT*zoom_factor);
+  if (!properties->zoom && zoom_factor > 1.)
+      zoom_factor = 1.;
+
+  canvas_width = BOARDWIDTH * zoom_factor;
+  canvas_height = BOARDHEIGHT * zoom_factor;
+
+  gtk_widget_set_size_request(canvas, canvas_width, canvas_height);
   goo_canvas_set_scale (GOO_CANVAS(canvas), zoom_factor);
-  gtk_fixed_move(GTK_FIXED(fixed), canvas,
-		 (screen_width-BOARDWIDTH*zoom_factor)/2,
-		 (screen_height-BOARDHEIGHT*zoom_factor)/2);
-
-  _expose_background_callback (drawing_area, NULL, NULL);
 
   return FALSE;
 }
@@ -331,6 +348,16 @@ board_widget_key_press_callback (GtkWidget   *widget,
       gc_fullscreen_set(TRUE);
     return TRUE;
   }
+  else if(event->state & GDK_CONTROL_MASK && ((event->keyval == GDK_m)
+					 || (event->keyval == GDK_M))) {
+    /* Toggle Mute */
+    if (mute)
+	gc_sound_bg_resume();
+    else
+	gc_sound_bg_pause();
+    mute = ! mute;
+    return TRUE;
+  }
 
   switch (event->keyval)
     {
@@ -426,6 +453,11 @@ board_widget_key_press_callback (GtkWidget   *widget,
   return FALSE;
 };
 
+guint gc_cursor_get()
+{
+  return gc_cursor_current;
+}
+
 void gc_cursor_set(guint gdk_cursor_type)
 {
   GdkCursor *cursor = NULL;
@@ -484,6 +516,7 @@ void gc_cursor_set(guint gdk_cursor_type)
 	gdk_pixbuf_unref(cursor_pixbuf);
       }
   }
+  gc_cursor_current = gdk_cursor_type;
 }
 
 /**
@@ -614,35 +647,14 @@ gc_set_default_background(GooCanvasItem *parent)
 			  "#BACKGROUND");
 }
 
-/* Redraw the black background
- */
-static gboolean
-_expose_background_callback (GtkWidget *widget,
-			     GdkEventExpose *event, gpointer data)
-{
-  gint screen_height, screen_width;
-
-  gdk_drawable_get_size(GDK_DRAWABLE (window->window),
-			&screen_width,
-			&screen_height);
-
-  gtk_widget_set_size_request (widget, screen_width, screen_height);
-  gdk_draw_rectangle (widget->window,
-		      widget->style->fg_gc[GTK_WIDGET_STATE (widget)],
-		      TRUE,
-		      0, 0, widget->allocation.width, widget->allocation.height);
-
-  return FALSE;
-}
-
-/*
- * Sugar requires properties to be set before the windows is realized
- */
 static gboolean
 _realize_callback (GtkWidget *widget, GdkEventExpose *event, gpointer data)
 {
+#ifdef USE_SUGAR
   Window xwindow = GDK_WINDOW_XWINDOW(window->window);
-
+  /*
+   * Sugar requires properties to be set before the windows is realized
+   */
   if (sugarBundleId)
     XChangeProperty(GDK_DISPLAY(),
 		    xwindow,
@@ -658,32 +670,44 @@ _realize_callback (GtkWidget *widget, GdkEventExpose *event, gpointer data)
 		    XInternAtom(GDK_DISPLAY(), "STRING", 0), 8,
 		    PropModeReplace,
 		    (unsigned char *) sugarActivityId, strlen(sugarActivityId));
+#endif
 
   return FALSE;
 }
 
 static void
-init_background()
+init_workspace()
 {
-  drawing_area = gtk_drawing_area_new ();
-  gtk_widget_set_size_request (drawing_area, BOARDWIDTH, BOARDHEIGHT);
-  g_signal_connect (G_OBJECT (drawing_area), "expose_event",
-		    G_CALLBACK (_expose_background_callback), NULL);
-  /* Create a vertical box in which I put first the play board area, then the button bar */
-  fixed = gtk_fixed_new ();
-  gtk_container_add(GTK_CONTAINER(window), GTK_WIDGET(fixed));
+  workspace = gtk_vbox_new(FALSE, 0);
+  gtk_container_add(GTK_CONTAINER(window), workspace);
 
-  gtk_fixed_put (GTK_FIXED(fixed), GTK_WIDGET(drawing_area), 0, 0);
-  gtk_fixed_put (GTK_FIXED(fixed), GTK_WIDGET(canvas), 0, 0);
+  GtkWidget *background = gtk_event_box_new();
+  GdkColor black = {0, 0, 0, 0};
+  gtk_widget_modify_bg(background, GTK_STATE_NORMAL, &black);
+  gtk_box_pack_end(GTK_BOX(workspace), background, TRUE, TRUE, 0);
 
-  gtk_widget_show (GTK_WIDGET(fixed));
-  gtk_widget_show (GTK_WIDGET(canvas));
+  alignment = gtk_alignment_new(.5, .5, 0., 0.);
+  g_signal_connect (GTK_OBJECT (alignment), "size-allocate",
+		      G_CALLBACK (_gc_size_allocate_event_callback), NULL);
+  gtk_container_add(GTK_CONTAINER(background), alignment);
 
-  gtk_widget_set_usize (GTK_WIDGET(canvas), BOARDWIDTH, BOARDHEIGHT);
+  gtk_container_add(GTK_CONTAINER(alignment), canvas);
+  gtk_widget_set_size_request (GTK_WIDGET(canvas), BOARDWIDTH, BOARDHEIGHT);
   goo_canvas_set_bounds (GOO_CANVAS(canvas),
 			 0, 0,
 			 BOARDWIDTH,
 			 BOARDHEIGHT);
+  g_object_set (G_OBJECT(canvas), "background-color", "#000", NULL);
+
+#ifdef MAC_INTEGRATION
+  GtkWidget *quit_item;
+  quit_item = gtk_menu_item_new();
+  ige_mac_menu_set_quit_menu_item(GTK_MENU_ITEM (quit_item));
+  gtk_signal_connect(GTK_OBJECT (quit_item),
+		     "activate", GTK_SIGNAL_FUNC (quit_cb), NULL);
+  gtk_widget_show (quit_item);
+
+#endif
 
 }
 
@@ -736,8 +760,6 @@ static GcomprisBoard *get_board_to_start()
 
 static void setup_window ()
 {
-  GcomprisBoard *board_to_start;
-
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
   /*
@@ -767,23 +789,6 @@ static void setup_window ()
 
   gtk_window_set_title(GTK_WINDOW (window), "GCompris");
 
-  GdkGeometry hints;
-  hints.base_width = 174;
-  hints.base_height = 144;
-  hints.min_width = 174;
-  hints.min_height = 144;
-  hints.width_inc = 1;
-  hints.height_inc = 1;
-  hints.min_aspect = (float)BOARDWIDTH/BOARDHEIGHT;
-  hints.max_aspect = (float)BOARDWIDTH/BOARDHEIGHT;
-  gtk_window_set_geometry_hints (GTK_WINDOW (window),
-				 NULL,
-				 &hints,
-				 GDK_HINT_RESIZE_INC |
-				 GDK_HINT_MIN_SIZE |
-				 GDK_HINT_BASE_SIZE |
-				 GDK_HINT_ASPECT);
-
   /*
    * Set the main window
    * -------------------
@@ -791,10 +796,8 @@ static void setup_window ()
 
   gtk_window_set_default_size(GTK_WINDOW(window), BOARDWIDTH, BOARDHEIGHT);
   gtk_window_set_wmclass(GTK_WINDOW(window), "gcompris", "GCompris");
-
   g_signal_connect (GTK_OBJECT (window), "realize",
 		    G_CALLBACK (_realize_callback), NULL);
-
   gtk_widget_realize (window);
 
   gtk_signal_connect (GTK_OBJECT (window), "delete_event",
@@ -803,14 +806,15 @@ static void setup_window ()
   gtk_signal_connect (GTK_OBJECT (window), "map_event",
 		      GTK_SIGNAL_FUNC (map_cb), NULL);
 
-  gtk_signal_connect (GTK_OBJECT (window), "configure_event",
-		      GTK_SIGNAL_FUNC (_gc_configure_event_callback), NULL);
-
   // Set the cursor
   gc_cursor_set(GCOMPRIS_DEFAULT_CURSOR);
 
   canvas     = goo_canvas_new();
 
+  g_object_set (canvas,
+		"has-tooltip", TRUE,
+		NULL);
+
   g_object_set (G_OBJECT(goo_canvas_get_root_item(GOO_CANVAS(canvas))),
 		"can-focus", TRUE,
 		NULL);
@@ -822,44 +826,16 @@ static void setup_window ()
 			  "key_press_event",
 			  GTK_SIGNAL_FUNC (board_widget_key_press_callback), 0);
 
+  gc_im_init(window);
+
+  init_workspace();
+
   GTK_WIDGET_SET_FLAGS (canvas, GTK_CAN_FOCUS);
   gtk_widget_grab_focus (canvas);
 
-  gc_im_init(window);
-
-  gc_board_init();
-
-  /* Load all the menu once */
-  gc_menu_load();
-
-  /* Save the root_menu */
-  properties->menu_board = gc_menu_section_get(properties->root_menu);
-
-  /* Run the bar */
-  gc_bar_start(GOO_CANVAS(canvas));
-
-  init_background();
-
-  board_to_start = get_board_to_start();
-
-  if(!board_to_start) {
-    gchar *tmpstr= g_strdup_printf("Couldn't find the board menu %s, or plugin execution error", properties->root_menu);
-    gc_dialog(tmpstr, NULL);
-    g_free(tmpstr);
-  } else if(!gc_board_check_file(board_to_start)) {
-    gchar *tmpstr= g_strdup_printf("Couldn't find the board menu, or plugin execution error");
-    gc_dialog(tmpstr, NULL);
-    g_free(tmpstr);
-  } else {
-    g_message("Fine, we got the gcomprisBoardMenu, xml boards parsing went fine");
-    if(!display_activation_dialog())
-      gc_board_play(board_to_start);
-  }
-
-
 }
 
-#ifdef STATIC_MODULE
+#ifdef ACTIVATION_CODE
 /** Display the activation dialog for the windows version
  *
  * return TRUE is the dialog is display, FALSE instead.
@@ -870,13 +846,18 @@ display_activation_dialog()
   int board_count = 0;
   int gc_board_number_in_demo = 0;
   GList *list;
-  guint  key_is_valid = 0;
+  gint  key_is_valid = 0;
 
   key_is_valid = gc_activation_check(properties->key);
 
   if(key_is_valid == 1)
     return FALSE;
-
+  else if(key_is_valid == 2)
+    {
+      g_free ( gc_prop_get()->key );
+      gc_prop_get()->key = strdup("");
+      gc_prop_save(properties);
+    }
   /* Count non menu boards */
   for (list = gc_menu_get_boards(); list != NULL; list = list->next)
     {
@@ -885,36 +866,29 @@ display_activation_dialog()
 	  strncmp(board->section, "/experimental", 13) != 0)
 	{
 	  board_count++;
-	  gc_board_check_file(board);
-	  if(board->plugin)
+	  if(board->demo)
 	      gc_board_number_in_demo++;
 	}
     }
 
   /* Entry area */
-  widget_activation_entry = (GtkEntry *)gtk_entry_new();
-  gtk_entry_set_max_length(widget_activation_entry, 6);
+  widget_activation_entry = gtk_entry_new();
+  gtk_entry_set_max_length(GTK_ENTRY(widget_activation_entry), 6);
   activation_item = \
-    goo_canvas_item_new (goo_canvas_get_root_item(canvas),
-			   goo_canvas_widget_get_type (),
-			   "widget", GTK_WIDGET(widget_activation_entry),
-			   "x", (double) BOARDWIDTH / 2 - 50,
-			   "y", (double) BOARDHEIGHT - 60,
-			   "width", 100.0,
-			   "height", 30.0,
-			   "anchor", GTK_ANCHOR_NW,
-			   "size_pixels", FALSE,
+    goo_canvas_widget_new (goo_canvas_get_root_item(GOO_CANVAS(canvas)),
+			   GTK_WIDGET(widget_activation_entry),
+			   BOARDWIDTH / 2 - 50,
+			   BOARDHEIGHT - 90,
+			   100.0,
+			   30.0,
 			   NULL);
   gtk_signal_connect(GTK_OBJECT(widget_activation_entry), "activate",
 		     GTK_SIGNAL_FUNC(activation_enter_callback),
 		     NULL);
 
-  gtk_widget_show(GTK_WIDGET(widget_activation_entry));
-  gtk_entry_set_text(GTK_ENTRY(widget_activation_entry), "CODE");
-
   char *msg = g_strdup_printf( \
       _("GCompris is free software released under the GPL License. "
-	"In order to support its development, the Windows version "
+	"In order to support its development, this version "
 	"provides only %d of the %d activities. You can get the "
 	"full version for a small fee at\n<http://gcompris.net>\n"
 	"The GNU/Linux version does not have this restriction. "
@@ -925,6 +899,9 @@ display_activation_dialog()
   gc_dialog(msg, activation_done);
   g_free(msg);
 
+  gtk_widget_show(GTK_WIDGET(widget_activation_entry));
+  gtk_entry_set_text(GTK_ENTRY(widget_activation_entry), "CODE");
+  gtk_widget_grab_focus(GTK_WIDGET(widget_activation_entry));
   return TRUE;
 }
 
@@ -932,8 +909,9 @@ display_activation_dialog()
  * Return -1 if the code is not valid
  *        0  if the code is valid but out of date
  *        1  if the code is valid and under 2 years
+ *        2  for the demo code
  */
-int gc_activation_check(const char *code)
+gint gc_activation_check(const char *code)
 {
 #ifdef  DISABLE_ACTIVATION_CODE
   return 1;
@@ -944,9 +922,19 @@ int gc_activation_check(const char *code)
   char crc2 = 0;
   char codeddate[5];
 
+  if (properties->administration)
+    return 1;
+
   if(strlen(code) != 6)
     return -1;
 
+  // A special code to test the full version without
+  // saving the activation
+  if (strncmp(code, "123321", 6) == 0)
+    {
+      return 2;
+    }
+
   for(i=3; i>=0; i--)
     {
       value |= code[i] & 0x07;
@@ -990,17 +978,11 @@ activation_enter_callback( GtkWidget *entry,
 			   GtkWidget *notused )
 {
   const char *code = gtk_entry_get_text(GTK_ENTRY(entry));
-  // A special code to test the full version without
-  // saving the activation
-  if (strncmp(code, "123321", 6) == 0)
-    {
-      gtk_entry_set_text(GTK_ENTRY(entry), "GOOD");
-      return;
-    }
 
   switch(gc_activation_check(code))
     {
     case 1:
+    case 2:
       gc_prop_get()->key = strdup(gtk_entry_get_text(GTK_ENTRY(entry)));
       gc_prop_save(properties);
       gtk_entry_set_text(GTK_ENTRY(entry), "GOOD");
@@ -1028,7 +1010,7 @@ activation_done()
     }
 
   gc_board_play( get_board_to_start());
-  gtk_object_destroy (GTK_OBJECT(activation_item));
+  goo_canvas_item_remove (activation_item);
 }
 #endif
 
@@ -1043,27 +1025,82 @@ void gc_board_end()
   }
 }
 
+void _set_geometry_hints(gboolean state)
+{
+  GdkGeometry hints;
+  hints.base_width = 615;
+  hints.base_height = 400;
+  hints.min_width = hints.base_width;
+  hints.min_height = hints.base_height;
+  hints.width_inc = 1;
+  hints.height_inc = 1;
+  hints.min_aspect = (float)BOARDWIDTH/BOARDHEIGHT;
+  if (state)
+    /* Warning: this is a workaround for GTK-OSX */
+    hints.max_aspect = (float)10; /* Fullscreen case */
+  else
+    hints.max_aspect = (float)BOARDWIDTH/BOARDHEIGHT;
+  gint geom_mask = GDK_HINT_RESIZE_INC |
+                   GDK_HINT_MIN_SIZE |
+                   GDK_HINT_BASE_SIZE;
+  if (!popt_sugar_look)
+      geom_mask |= GDK_HINT_ASPECT;
+  gtk_window_set_geometry_hints (GTK_WINDOW (window), NULL, &hints, geom_mask);
+}
+
 /** \brief toggle full screen mode
  *
  *
  */
 void gc_fullscreen_set(gboolean state)
 {
+  static gint window_x = 0;
+  static gint window_y = 0;
+  static gint window_w = BOARDWIDTH;
+  static gint window_h = BOARDHEIGHT;
+
   fullscreen = state;
+  _set_geometry_hints(state);
   if(state)
     {
-      gdk_window_set_decorations (window->window, 0);
-      gtk_window_fullscreen (GTK_WINDOW(window));
-      gtk_widget_set_uposition (window, 0, 0);
+      gtk_window_get_position ( (GtkWindow*)( window ), &window_x, &window_y );
+      gtk_window_get_size ( GTK_WINDOW ( window ), &window_w, &window_h );
+#ifdef WIN32
+      // WARNING: Doing this is required on Windows
+      //          but keep the window hidden on GNU/Linux
+      gtk_widget_hide ( window );
+#elif MAC_INTEGRATION
+      // WARNING: Doing this is required on MacOSX
+      //          but keep the window hidden on GNU/Linux
+      gtk_widget_hide ( window );
+#else
+#endif
+      gtk_window_set_decorated ( GTK_WINDOW ( window ), FALSE );
+      gtk_window_set_type_hint ( GTK_WINDOW ( window ),
+				 GDK_WINDOW_TYPE_HINT_DESKTOP );
+      if (popt_sugar_look)
+	gtk_window_maximize ( GTK_WINDOW( window ) );
+      else
+        gtk_window_fullscreen ( GTK_WINDOW ( window ) );
+
+      gtk_window_move ( GTK_WINDOW ( window ), 0, 0 );
+
+      GdkScreen *screen = gtk_window_get_screen ( GTK_WINDOW ( window ) );
+      gtk_window_resize ( GTK_WINDOW ( window ),
+			  gdk_screen_get_width (screen),
+			  gdk_screen_get_height (screen) );
     }
   else
     {
-      gdk_window_set_decorations (window->window, GDK_DECOR_ALL);
-      gtk_window_unfullscreen (GTK_WINDOW(window));
-
-      /* Mandatory or on windows we get iconified */
-      gtk_window_deiconify (GTK_WINDOW(window));
+      gtk_widget_hide ( window );
+      gtk_window_set_type_hint ( GTK_WINDOW ( window ),
+				 GDK_WINDOW_TYPE_HINT_NORMAL );
+      gtk_window_unfullscreen ( GTK_WINDOW ( window ) );
+      gtk_window_set_decorated ( GTK_WINDOW ( window ), TRUE );
+      gtk_window_move ( GTK_WINDOW ( window ), window_x, window_y );
+      gtk_window_resize ( GTK_WINDOW ( window ), window_w, window_h );
     }
+  gtk_window_present ( GTK_WINDOW ( window ) );
 
 }
 
@@ -1132,8 +1169,40 @@ static void map_cb (GtkWidget *widget, gpointer data)
 {
   if(is_mapped == FALSE)
     {
-      gc_fullscreen_set(properties->fullscreen);
       is_mapped = TRUE;
+      GcomprisBoard *board_to_start;
+
+      gc_set_default_background (goo_canvas_get_root_item (GOO_CANVAS(canvas)));
+
+      gc_fullscreen_set(properties->fullscreen);
+
+      gc_status_init("");
+      gc_board_init();
+      /* Load all the menu once */
+      gc_menu_load();
+      /* Save the root_menu */
+      properties->menu_board = gc_menu_section_get(properties->root_menu);
+
+      gc_bar_start(GTK_CONTAINER(workspace), GOO_CANVAS(canvas));
+
+      gc_status_close();
+
+      board_to_start = get_board_to_start();
+
+      if(!board_to_start) {
+	gchar *tmpstr= g_strdup_printf("Couldn't find the board menu %s, or plugin execution error", properties->root_menu);
+	gc_dialog(tmpstr, NULL);
+	g_free(tmpstr);
+      } else if(!gc_board_check_file(board_to_start)) {
+	gchar *tmpstr= g_strdup_printf("Couldn't find the board menu, or plugin execution error");
+	gc_dialog(tmpstr, NULL);
+	g_free(tmpstr);
+      } else {
+	g_message("Fine, we got the gcomprisBoardMenu, xml boards parsing went fine");
+	if(!display_activation_dialog())
+	  gc_board_play(board_to_start);
+      }
+
     }
   g_message("gcompris window is now mapped");
 }
@@ -1153,24 +1222,24 @@ void gc_terminate(int signum)
 
 static void load_properties ()
 {
+  GError *error = NULL;
   properties = gc_prop_new ();
 
   /* Initialize the binary relocation API
    *  http://autopackage.org/docs/binreloc/
    */
-  if(gbr_init (NULL))
+  if(gbr_init (&error))
     g_message("Binary relocation enabled");
   else
-    g_message("Binary relocation disabled");
+    {
+      if (error->code == GBR_INIT_ERROR_DISABLED)
+	g_message("Binary relocation disabled");
+      else
+	g_message("Binary relocation start failed with error %d", error->code);
+      g_error_free (error);
+    }
 
-  /* usefull for OSX bundle app */
-  /* FIXME exec_prefix should be put in properties */
-  /* usefull for OSX bundle app */
-#ifdef NSBUNDLE
-  exec_prefix = gcompris_nsbundle_resource ();
-#else
   exec_prefix = gbr_find_exe_dir(NULL);
-#endif
   g_warning("exec_prefix %s\n", (exec_prefix==NULL ? "NONE" : exec_prefix));
 
   {
@@ -1310,6 +1379,13 @@ void gc_log_handler (const gchar *log_domain,
     g_printerr ("%s: %s\n\n", "gcompris", message);
 }
 
+/* Refresh canvas zoom e.g. after setting zoom setting */
+void
+gc_update_canvas_zoom()
+{
+  _gc_size_allocate_event_callback(NULL, &alignment->allocation, NULL);
+}
+
 static void
 start_bg_music (gchar *file)
 {
@@ -1501,9 +1577,6 @@ main (int argc, char *argv[])
       g_message("Default gnome cursor enabled");
       properties->defaultcursor = GDK_LEFT_PTR;
     }
-#ifdef WIN32
-  properties->defaultcursor = GDK_LEFT_PTR;
-#endif
 
   if (popt_experimental)
     {
@@ -1782,6 +1855,23 @@ main (int argc, char *argv[])
     exit(0);
   }
 
+  if (popt_sugar_look){
+    #ifdef USE_SUGAR
+      extern Bar sugar_bar;
+      gc_bar_register(&sugar_bar);
+      extern Score sugar_score;
+      gc_score_register(&sugar_score);
+    #else
+	  printf("GCompris was not built with Sugar DE support.\n");
+      popt_sugar_look = FALSE;
+    #endif
+  }
+
+  if (popt_no_zoom){
+    g_message("Zoom disabled");
+    properties->zoom = FALSE;
+  }
+
   /*------------------------------------------------------------*/
 
   single_instance_check();
@@ -1806,6 +1896,12 @@ main (int argc, char *argv[])
 
   gtk_widget_show_all (window);
 
+
+  if(properties->music || properties->fx)
+    mute = FALSE;
+  else
+    mute = TRUE;
+
   /* If a specific activity is selected, skeep the intro music */
   if(!popt_root_menu)
     {
@@ -1820,10 +1916,22 @@ main (int argc, char *argv[])
 	gc_sound_play_ogg("voices/$LOCALE/misc/welcome.ogg", NULL);
     }
 
+#ifndef WIN32
   if (sugarActivityId)
     gc_dbus_init(sugarActivityId);
+#endif
 
   gtk_main ();
 
   return(0);
 }
+
+gint
+gc_timing (gint timeout, gint actors_number)
+{
+  if (popt_timing_base > 1.0)
+    timeout = (int) (timeout * popt_timing_base);
+  if (popt_timing_mult < 1.0 && actors_number > 1)
+    timeout += (int) (timeout * actors_number * popt_timing_mult);
+  return timeout;
+}
