@@ -19,6 +19,7 @@
 #include <string.h>
 
 #include "gcompris.h"
+#include "status.h"
 #include <glib/gstdio.h>
 
 #ifdef USE_SQLITE
@@ -33,6 +34,10 @@ static char *escape_quote(const char *input);
 static sqlite3 *gcompris_db=NULL;
 #endif
 
+// Increase this when the database schema changes
+// but does not change the PRAGMA SCHEMA VERSION
+#define SCHEMA_USER_VERSION 1
+
 #define CREATE_TABLE_USERS						\
   "CREATE TABLE users (user_id INT UNIQUE, login TEXT, lastname TEXT, firstname TEXT, birthdate TEXT, class_id INT ); "
 #define CREATE_TABLE_CLASS						\
@@ -50,7 +55,7 @@ static sqlite3 *gcompris_db=NULL;
 #define CREATE_TABLE_BOARDS_PROFILES_CONF				\
   "CREATE TABLE board_profile_conf (profile_id INT, board_id INT, conf_key TEXT, conf_value TEXT ); "
 #define CREATE_TABLE_BOARDS						\
-  "CREATE TABLE boards (board_id INT UNIQUE, name TEXT, section_id INT, section TEXT, author TEXT, type TEXT, mode TEXT, difficulty INT, icon TEXT, boarddir TEXT, mandatory_sound_file TEXT, mandatory_sound_dataset TEXT, filename TEXT, title TEXT, description TEXT, prerequisite TEXT, goal TEXT, manual TEXT, credit TEXT);"
+  "CREATE TABLE boards (board_id INT UNIQUE, name TEXT, section_id INT, section TEXT, author TEXT, type TEXT, mode TEXT, difficulty INT, icon TEXT, boarddir TEXT, mandatory_sound_file TEXT, mandatory_sound_dataset TEXT, filename TEXT, title TEXT, description TEXT, prerequisite TEXT, goal TEXT, manual TEXT, credit TEXT, demo INT);"
 #define CREATE_TABLE_LOGS						\
   "CREATE TABLE logs (date TEXT, duration INT, user_id INT, board_id INT, level INT, sublevel INT, status INT, comment TEXT);"
 
@@ -63,6 +68,12 @@ static sqlite3 *gcompris_db=NULL;
 #define PRAGMA_SCHEMA_VERSION			\
   "PRAGMA schema_version; "
 
+#define PRAGMA_USER_VERSION			\
+  "PRAGMA user_version; "
+
+#define PRAGMA_USER_VERSION_SET(v)		\
+  "PRAGMA user_version=\'%d\';", v
+
 /* WARNING: template for g_strdup_printf */
 #define SET_VERSION(v)							\
   "INSERT INTO informations (gcompris_version) VALUES(\'%s\'); ", v
@@ -123,6 +134,262 @@ static sqlite3 *gcompris_db=NULL;
      END;"
 
 
+/* Return the user version of the database
+ * or -1 if failed. The user version is an sqlite
+ * specific information stored in the pragma
+ * user_version
+ */
+static gint
+_get_user_version()
+{
+  char **result;
+  int nrow;
+  int ncolumn;
+  char *zErrMsg;
+  int rc;
+
+  /* Check the db integrity */
+  rc = sqlite3_get_table(gcompris_db,
+			 PRAGMA_USER_VERSION,
+			 &result,
+			 &nrow,
+			 &ncolumn,
+			 &zErrMsg
+			 );
+  if( rc!=SQLITE_OK )
+    {
+      g_message("SQL error: %s\n", zErrMsg);
+      return -1;
+    }
+
+  gint user_version = atoi(result[1]);
+  sqlite3_free_table(result);
+
+  return user_version;
+}
+
+/* Set the user version of the database.
+ * The user version is an sqlite
+ * specific information stored in the pragma
+ * user_version
+ */
+static void
+_set_user_version(gint version)
+{
+  char **result;
+  int nrow;
+  int ncolumn;
+  char *zErrMsg;
+  int rc;
+  gchar *request;
+
+  request = g_strdup_printf(PRAGMA_USER_VERSION_SET(version));
+
+  rc = sqlite3_get_table(gcompris_db,
+			 request,
+			 &result,
+			 &nrow,
+			 &ncolumn,
+			 &zErrMsg
+			 );
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+  g_free(request);
+}
+
+static void _create_db()
+{
+  gchar *request;
+  char *zErrMsg;
+  char **result;
+  int rc;
+  int nrow;
+  int ncolumn;
+
+  /* create all tables needed */
+  rc = sqlite3_exec(gcompris_db,CREATE_TABLE_USERS, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+  rc = sqlite3_exec(gcompris_db,CREATE_TABLE_CLASS, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+  rc = sqlite3_exec(gcompris_db,CREATE_TABLE_GROUPS, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+  rc = sqlite3_exec(gcompris_db,CREATE_TABLE_USERS_IN_GROUPS, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+  rc = sqlite3_exec(gcompris_db,CREATE_TABLE_GROUPS_IN_PROFILES, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+  rc = sqlite3_exec(gcompris_db,CREATE_TABLE_ACTIVITIES_OUT, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+  rc = sqlite3_exec(gcompris_db,CREATE_TABLE_PROFILES, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+  rc = sqlite3_exec(gcompris_db,CREATE_TABLE_BOARDS_PROFILES_CONF, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+  rc = sqlite3_exec(gcompris_db,CREATE_TABLE_BOARDS, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+  rc = sqlite3_exec(gcompris_db,CREATE_TABLE_INFO, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+  rc = sqlite3_exec(gcompris_db,CREATE_TABLE_LOGS, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+
+  /* CREATE TRIGGERS */
+  rc = sqlite3_exec(gcompris_db,TRIGGER_DELETE_CLASS, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+  rc = sqlite3_exec(gcompris_db,TRIGGER_DELETE_GROUPS, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+  rc = sqlite3_exec(gcompris_db,TRIGGER_DELETE_PROFILES, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+  rc = sqlite3_exec(gcompris_db,TRIGGER_DELETE_USERS, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+  rc = sqlite3_exec(gcompris_db,TRIGGER_INSERT_USERS, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+  rc = sqlite3_exec(gcompris_db,TRIGGER_UPDATE_USERS, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+
+  g_message("Database tables created");
+
+  request = g_strdup_printf(SET_VERSION(VERSION));
+
+  rc = sqlite3_get_table(gcompris_db,
+			 request,
+			 &result,
+			 &nrow,
+			 &ncolumn,
+			 &zErrMsg
+			 );
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+
+  rc = sqlite3_exec(gcompris_db,SET_DEFAULT_PROFILE, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+
+  rc = sqlite3_exec(gcompris_db,ACTIVATE_DEFAULT_PROFILE, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+
+
+  request = g_strdup_printf("INSERT INTO class (class_id, name, teacher, wholegroup_id) VALUES ( 1, \"%s\", \"(%s)\", 1);",
+			    _("Unaffected"),
+			    _("Users without a class"));
+
+  rc = sqlite3_exec(gcompris_db, request, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+
+  rc = sqlite3_exec(gcompris_db,SET_DEFAULT_GROUP, NULL,  0, &zErrMsg);
+  if( rc!=SQLITE_OK ){
+    g_error("SQL error: %s\n", zErrMsg);
+  }
+
+
+  sqlite3_free_table(result);
+
+  g_free(request);
+
+  _set_user_version(SCHEMA_USER_VERSION);
+}
+
+static gboolean
+_check_db_integrity()
+{
+  char **result;
+  int nrow;
+  int ncolumn;
+  char *zErrMsg;
+  int rc;
+
+  /* Check the db integrity */
+  rc = sqlite3_get_table(gcompris_db,
+			 PRAGMA_INTEGRITY,
+			 &result,
+			 &nrow,
+			 &ncolumn,
+			 &zErrMsg
+			 );
+  if( rc!=SQLITE_OK )
+    {
+      g_message("SQL error: %s\n", zErrMsg);
+      return FALSE;
+    }
+
+  if (!(strcmp(result[1],"ok")==0))
+    {
+      g_message("DATABASE integrity check returns %s \n", result[1]);
+      return FALSE;
+    }
+
+    sqlite3_free_table(result);
+
+    return TRUE;
+}
+
+/* Return the number of boards in the boards table
+ */
+gint _gc_boards_count()
+{
+  char **result;
+  int nrow;
+  int ncolumn;
+  char *zErrMsg;
+  int rc;
+
+  /* Check the db integrity */
+  rc = sqlite3_get_table(gcompris_db,
+			 "SELECT COUNT(*) FROM boards;",
+			 &result,
+			 &nrow,
+			 &ncolumn,
+			 &zErrMsg
+			 );
+  if( rc!=SQLITE_OK )
+    {
+      g_message("SQL error: %s\n", zErrMsg);
+      return FALSE;
+    }
+
+  gint count = atoi(result[1]);
+  sqlite3_free_table(result);
+  return count;
+}
+
 gboolean gc_db_init(gboolean disable_database_)
 {
 
@@ -135,178 +402,55 @@ gboolean gc_db_init(gboolean disable_database_)
   int rc;
   int nrow;
   int ncolumn;
-  gchar *request;
 
   GcomprisProperties	*properties = gc_prop_get();
 
   if (!g_file_test(properties->database, G_FILE_TEST_EXISTS))
     creation = TRUE;
 
-#ifndef WIN32
-    /* this stat() does not work on WinXP */
-    /* NEEDS CHECKING IN WINXP */
-
-  else {
-    /* we have to check this file is not empty,
-       because bug in administration */
-    struct stat buf;
-
-    if (g_stat(properties->database, &buf)!=0)
-      g_error("Can't stat %s", properties->database);
-
-    /* if size of file is null, we recreate the tables */
-    if (buf.st_size == 0){
-      creation = TRUE;
-      g_message("Database file is empty! Trying to create table...");
-    }
-  }
-#endif
-
   rc = sqlite3_open(properties->database, &gcompris_db);
   if( rc ){
-    g_message("Can't open database %s : %s\n", properties->database, sqlite3_errmsg(gcompris_db));
+    g_message("Can't open database %s : %s\n", properties->database,
+	      sqlite3_errmsg(gcompris_db));
     sqlite3_close(gcompris_db);
-    exit(1);
+    disable_database = TRUE;
+    return FALSE;
   }
 
   g_message("Database %s opened", properties->database);
 
   if (creation){
-    /* create all tables needed */
-    rc = sqlite3_exec(gcompris_db,CREATE_TABLE_USERS, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-    rc = sqlite3_exec(gcompris_db,CREATE_TABLE_CLASS, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-    rc = sqlite3_exec(gcompris_db,CREATE_TABLE_GROUPS, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-    rc = sqlite3_exec(gcompris_db,CREATE_TABLE_USERS_IN_GROUPS, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-    rc = sqlite3_exec(gcompris_db,CREATE_TABLE_GROUPS_IN_PROFILES, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-    rc = sqlite3_exec(gcompris_db,CREATE_TABLE_ACTIVITIES_OUT, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-    rc = sqlite3_exec(gcompris_db,CREATE_TABLE_PROFILES, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-    rc = sqlite3_exec(gcompris_db,CREATE_TABLE_BOARDS_PROFILES_CONF, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-    rc = sqlite3_exec(gcompris_db,CREATE_TABLE_BOARDS, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-    rc = sqlite3_exec(gcompris_db,CREATE_TABLE_INFO, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-    rc = sqlite3_exec(gcompris_db,CREATE_TABLE_LOGS, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-
-    /* CREATE TRIGGERS */
-    rc = sqlite3_exec(gcompris_db,TRIGGER_DELETE_CLASS, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-    rc = sqlite3_exec(gcompris_db,TRIGGER_DELETE_GROUPS, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-    rc = sqlite3_exec(gcompris_db,TRIGGER_DELETE_PROFILES, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-    rc = sqlite3_exec(gcompris_db,TRIGGER_DELETE_USERS, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-    rc = sqlite3_exec(gcompris_db,TRIGGER_INSERT_USERS, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-    rc = sqlite3_exec(gcompris_db,TRIGGER_UPDATE_USERS, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-
-    g_message("Database tables created");
-
-    request = g_strdup_printf(SET_VERSION(VERSION));
-
-    rc = sqlite3_get_table(gcompris_db,
-			   request,
-			   &result,
-			   &nrow,
-			   &ncolumn,
-			   &zErrMsg
-			   );
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-
-    rc = sqlite3_exec(gcompris_db,SET_DEFAULT_PROFILE, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-
-    rc = sqlite3_exec(gcompris_db,ACTIVATE_DEFAULT_PROFILE, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-
-
-    request = g_strdup_printf("INSERT INTO class (class_id, name, teacher, wholegroup_id) VALUES ( 1, \"%s\", \"(%s)\", 1);",
-			      _("Unaffected"),
-			      _("Users without a class"));
-
-    rc = sqlite3_exec(gcompris_db, request, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-
-    rc = sqlite3_exec(gcompris_db,SET_DEFAULT_GROUP, NULL,  0, &zErrMsg);
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
-
-
-    sqlite3_free_table(result);
-
-    g_free(request);
-
+    _create_db();
   } else {
-    /* Check the db integrity */
-    rc = sqlite3_get_table(gcompris_db,
-			   PRAGMA_INTEGRITY,
-			   &result,
-			   &nrow,
-			   &ncolumn,
-			   &zErrMsg
-			   );
-    if( rc!=SQLITE_OK ){
-      g_error("SQL error: %s\n", zErrMsg);
-    }
+    if ( ! _check_db_integrity() ||
+	 _gc_boards_count() == 0 )
+      {
+	// We failed to load the database, let's
+	// backup it and re create it.
+	sqlite3_close(gcompris_db);
+	gchar *backup = g_strdup_printf("%s.broken", properties->database);
+	g_rename(properties->database, backup);
+	g_message("Database is broken, it is copyed in %s", backup);
+	g_free(backup);
 
-    if (!(strcmp(result[1],"ok")==0))
-      g_error("DATABASE integrity check returns %s \n", result[1]);
+	rc = sqlite3_open(properties->database, &gcompris_db);
+	if( rc ){
+	  g_message("Can't open database %s : %s\n", properties->database,
+		    sqlite3_errmsg(gcompris_db));
+	  sqlite3_close(gcompris_db);
+	  disable_database = TRUE;
+	  return FALSE;
+	}
+	_create_db();
+
+	if ( ! _check_db_integrity() )
+	  {
+	    disable_database = TRUE;
+	    return FALSE;
+	  }
+      }
 
     g_message("Database Integrity ok");
-    sqlite3_free_table(result);
 
     rc = sqlite3_get_table(gcompris_db,
 			   CHECK_VERSION,
@@ -345,6 +489,21 @@ gboolean gc_db_init(gboolean disable_database_)
 	  g_error("SQL error: %s\n", zErrMsg);
 	}
       }
+    if ( _get_user_version() == 0)
+      {
+	g_message("Upgrading schema based on user version = 0\n");
+	rc = sqlite3_exec(gcompris_db,"DROP TABLE boards;", NULL,  0, &zErrMsg);
+	if( rc!=SQLITE_OK ) {
+	  g_error("SQL error: %s\n", zErrMsg);
+	}
+	rc = sqlite3_exec(gcompris_db,CREATE_TABLE_BOARDS, NULL,  0, &zErrMsg);
+	if( rc!=SQLITE_OK ) {
+	  g_error("SQL error: %s\n", zErrMsg);
+	}
+	// We just dropped the boards table, force a reread
+	properties->reread_menu = TRUE;
+	_set_user_version(1);
+      }
   }
 
   return TRUE;
@@ -468,7 +627,7 @@ gboolean gc_db_check_boards()
 
 
 #define GC_BOARD_INSERT							\
-  "INSERT OR REPLACE INTO boards VALUES (%d, %Q, %d, %Q, %Q, %Q, %Q, %d, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q);"
+  "INSERT OR REPLACE INTO boards VALUES (%d, %Q, %d, %Q, %Q, %Q, %Q, %d, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %d);"
 
 #define MAX_GC_BOARD_ID				\
   "SELECT MAX(board_id) FROM boards;"
@@ -502,7 +661,8 @@ gc_db_board_update(guint *board_id,
 		   gchar *prerequisite,
 		   gchar *goal,
 		   gchar *manual,
-		   gchar *credit
+		   gchar *credit,
+		   int demo
 		   )
 {
   SUPPORT_OR_RETURN(FALSE);
@@ -632,7 +792,8 @@ gc_db_board_update(guint *board_id,
 			     prerequisite,
 			     goal,
 			     manual,
-			     credit
+			     credit,
+			     demo
 			     );
 
   rc = sqlite3_get_table(gcompris_db,
@@ -657,7 +818,7 @@ gc_db_board_update(guint *board_id,
 
 
 #define BOARDS_READ							\
-  "SELECT board_id ,name, section_id, section, author, type, mode, difficulty, icon, boarddir, mandatory_sound_file, mandatory_sound_dataset, filename, title, description, prerequisite, goal, manual, credit FROM boards;"
+  "SELECT board_id ,name, section_id, section, author, type, mode, difficulty, icon, boarddir, mandatory_sound_file, mandatory_sound_dataset, filename, title, description, prerequisite, goal, manual, credit, demo FROM boards;"
 
 GList *gc_menu_load_db(GList *boards_list)
 {
@@ -726,8 +887,13 @@ GList *gc_menu_load_db(GList *boards_list)
     gcomprisBoard->goal = reactivate_newline(gettext(result[i++]));
     gcomprisBoard->manual = reactivate_newline(gettext(result[i++]));
     gcomprisBoard->credit = reactivate_newline(gettext(result[i++]));
+    gcomprisBoard->demo = atoi(result[i++]);
 
     boards = g_list_append(boards, gcomprisBoard);
+    gchar *msg = g_strdup_printf(_("Loading activity from database:\n%s"),
+				 gettext(gcomprisBoard->title));
+    gc_status_set_msg(msg);
+    g_free(msg);
   }
 
   sqlite3_free_table(result);
@@ -1703,7 +1869,7 @@ GList *gc_db_get_groups_list()
 
 
 #define BOARDS_READ_FROM_ID(n)						\
-  "SELECT name, section_id, section, author, type, mode, difficulty, icon, boarddir, mandatory_sound_file, mandatory_sound_dataset, filename, title, description, prerequisite, goal, manual, credit FROM boards WHERE board_id=%d;",n
+  "SELECT name, section_id, section, author, type, mode, difficulty, icon, boarddir, mandatory_sound_file, mandatory_sound_dataset, filename, title, description, prerequisite, goal, manual, credit, demo FROM boards WHERE board_id=%d;",n
 
 GcomprisBoard *gc_db_get_board_from_id(int board_id)
 {
@@ -1775,6 +1941,7 @@ GcomprisBoard *gc_db_get_board_from_id(int board_id)
   gcomprisBoard->goal = reactivate_newline(gettext(result[i++]));
   gcomprisBoard->manual = reactivate_newline(gettext(result[i++]));
   gcomprisBoard->credit = reactivate_newline(gettext(result[i++]));
+  gcomprisBoard->demo = atoi(result[i++]);
 
   sqlite3_free_table(result);
 
