@@ -1,6 +1,6 @@
 /* gcompris - images_selector.c
  *
- * Copyright (C) 2000 Bruno Coudoin
+ * Copyright (C) 2000, 2008 Bruno Coudoin
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -28,35 +28,37 @@
 #include <libxml/parser.h>
 
 #include "gcompris.h"
+#include "gc_core.h"
 
 #define SOUNDLISTFILE PACKAGE
 
-static gint		 item_event_images_selector(GnomeCanvasItem *item,
+static gint		 item_event_images_selector(GooCanvasItem *item,
+						    GooCanvasItem *target,
 						    GdkEvent *event,
-						    gpointer data);
-static gint		 item_event_imageset_selector(GnomeCanvasItem *item,
+						    gchar *data);
+static gint		 item_event_imageset_selector(GooCanvasItem *item,
 						      GdkEvent *event,
 						      gpointer data);
-static gint		 item_event_scroll(GnomeCanvasItem *item,
-					   GdkEvent *event,
-					   GnomeCanvas *canvas);
-static gboolean		 read_xml_file(gchar *fname);
+static void		 item_event_scroll(GtkAdjustment *adj,
+					   GooCanvas *canvas);
+static gboolean          read_xml_file(gchar *fname);
 static gboolean		 read_dataset_directory(gchar *dataset_dir);
-static void		 display_image(gchar *imagename, GnomeCanvasItem *rootitem);
-static void		 free_stuff (GtkObject *obj, GSList *data);
+static void		 display_image(gchar *imagename, GooCanvasItem *rootitem);
+static void		 free_stuff (GSList *data);
 
 static gboolean		 images_selector_displayed = FALSE;
 
-static GnomeCanvasItem	*rootitem = NULL;
-static GnomeCanvasItem	*current_root_set = NULL;
+static GooCanvasItem	*rootitem = NULL;
+static GooCanvasItem	*current_root_set = NULL;
 
-static GnomeCanvas	*canvas_list_selector; /* The scrolled left part */
-static GnomeCanvasItem  *list_bg_item;
+static GtkWidget	*canvas_list_selector; /* The scrolled left part */
+static GooCanvasItem	*list_bg_item;
 
-static GnomeCanvas	*canvas_image_selector; /* The scrolled right part */
-static GnomeCanvasItem  *image_bg_item;
+static GtkWidget	*canvas_image_selector; /* The scrolled right part */
+static GooCanvasItem    *image_bg_item;
 
 static ImageSelectorCallBack imageSelectorCallBack = NULL;
+static void *current_user_context = NULL;
 
 static gboolean		 display_in_progress;
 
@@ -64,7 +66,7 @@ static gboolean		 display_in_progress;
 #define	DRAWING_AREA_X1	111.0
 #define DRAWING_AREA_Y1	14.0
 #define DRAWING_AREA_X2	774.0
-#define DRAWING_AREA_Y2	500.0
+#define DRAWING_AREA_Y2	460.0
 
 /* Represent the limits of list area */
 #define	LIST_AREA_X1	18.0
@@ -74,7 +76,7 @@ static gboolean		 display_in_progress;
 #define VERTICAL_NUMBER_OF_LIST_IMAGE	6
 
 #define HORIZONTAL_NUMBER_OF_IMAGE	8
-#define VERTICAL_NUMBER_OF_IMAGE	4
+#define VERTICAL_NUMBER_OF_IMAGE	6
 #define IMAGE_GAP			10
 
 #define IMAGE_WIDTH  (DRAWING_AREA_X2-DRAWING_AREA_X1)/HORIZONTAL_NUMBER_OF_IMAGE-IMAGE_GAP
@@ -83,9 +85,12 @@ static gboolean		 display_in_progress;
 #define LIST_IMAGE_WIDTH  LIST_AREA_X2-LIST_AREA_X1-IMAGE_GAP
 #define LIST_IMAGE_HEIGHT (LIST_AREA_Y2-LIST_AREA_Y1)/VERTICAL_NUMBER_OF_LIST_IMAGE-IMAGE_GAP
 
-static guint		 ix;
-static guint		 iy;
-static guint		 isy;
+static double		 ix;
+static double		 iy;
+static double		 isy;
+
+static GtkAdjustment    *list_adj;
+static GtkAdjustment    *image_adj;
 
 /*
  * Main entry point
@@ -99,17 +104,15 @@ static guint		 isy;
 
 void
 gc_selector_images_start (GcomprisBoard *gcomprisBoard, gchar *dataset,
-				ImageSelectorCallBack iscb)
+			  ImageSelectorCallBack iscb,
+			  void *user_context)
 {
 
-  GnomeCanvasItem *item, *item2;
-  GdkPixbuf	*pixmap = NULL;
-  gint		 y = 0;
+  GooCanvasItem *item;
   gint		 y_start = 0;
-  gint		 x_start = 0;
   gchar		*dataseturl = NULL;
 
-  GtkWidget	  *w;
+  GtkWidget	*w;
 
   if(rootitem)
     return;
@@ -118,133 +121,135 @@ gc_selector_images_start (GcomprisBoard *gcomprisBoard, gchar *dataset,
 
   gc_board_pause(TRUE);
 
-  imageSelectorCallBack=iscb;
+  imageSelectorCallBack = iscb;
+  current_user_context = user_context;
 
-  rootitem = \
-    gnome_canvas_item_new (gnome_canvas_root(gc_get_canvas()),
-			   gnome_canvas_group_get_type (),
-			   "x", (double)0,
-			   "y", (double)0,
-			   NULL);
+  rootitem = goo_canvas_group_new (goo_canvas_get_root_item(gc_get_canvas()),
+				   NULL);
 
   images_selector_displayed = TRUE;
 
-  pixmap = gc_skin_pixmap_load("images_selector_bg.png");
-  y_start = (BOARDHEIGHT - gdk_pixbuf_get_height(pixmap))/2;
-  x_start = (BOARDWIDTH - gdk_pixbuf_get_width(pixmap))/2;
-  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap,
-				"x", (double) x_start,
-				"y", (double) y_start,
-				NULL);
-  y = BOARDHEIGHT - (BOARDHEIGHT - gdk_pixbuf_get_height(pixmap))/2;
-  gdk_pixbuf_unref(pixmap);
+  item = goo_canvas_svg_new (rootitem,
+			     gc_skin_rsvg_get(),
+			     "svg-id", "#IMAGE_SELECTOR",
+			     "pointer-events", GOO_CANVAS_EVENTS_NONE,
+			     NULL);
 
   y_start += 110;
 
-  pixmap = gc_skin_pixmap_load("button_large.png");
-
   /*
    * Create the list scrollbar
    * -------------------------
    */
-  canvas_list_selector     = GNOME_CANVAS(gnome_canvas_new ());
+  canvas_list_selector = goo_canvas_new ();
 
-  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-			 gnome_canvas_widget_get_type (),
-			 "widget", GTK_WIDGET(canvas_list_selector),
-			 "x", (double) LIST_AREA_X1,
-			 "y", (double) LIST_AREA_Y1,
-			 "width",  LIST_AREA_X2 - LIST_AREA_X1,
-			 "height", LIST_AREA_Y2 - LIST_AREA_Y1 - 35.0,
+  goo_canvas_widget_new (rootitem,
+			 canvas_list_selector,
+			 LIST_AREA_X1,
+			 LIST_AREA_Y1,
+			 LIST_AREA_X2 - LIST_AREA_X1,
+			 LIST_AREA_Y2 - LIST_AREA_Y1 - 35.0,
 			 NULL);
 
-  gtk_widget_show (GTK_WIDGET(canvas_list_selector));
+  gtk_widget_show (canvas_list_selector);
 
   /* Set the new canvas to the background color or it's white */
-  list_bg_item = gnome_canvas_item_new (gnome_canvas_root(canvas_list_selector),
-					gnome_canvas_rect_get_type (),
-					"x1", (double) 0,
-					"y1", (double) 0,
-					"x2", (double) LIST_AREA_X2 - LIST_AREA_X1,
-					"y2", (double) LIST_AREA_Y2 - LIST_AREA_Y1,
-					"fill_color_rgba", gc_skin_get_color("gcompris/imageselectbg"),
-					NULL);
+  list_bg_item = goo_canvas_rect_new (goo_canvas_get_root_item(GOO_CANVAS(canvas_list_selector)),
+				      0,
+				      0,
+				      (LIST_AREA_X2 - LIST_AREA_X1)
+				      * gc_zoom_factor_get(),
+				      (LIST_AREA_Y2 - LIST_AREA_Y1)
+				      * gc_zoom_factor_get(),
+				      "fill-color-rgba",
+				      gc_skin_get_color("gcompris/imageselectbg_left"),
+				      "line-width", 0.0,
+				      NULL);
 
+  list_adj = \
+    GTK_ADJUSTMENT (gtk_adjustment_new (0.00, 0.00,
+					0.00,
+					10, IMAGE_HEIGHT,
+					(LIST_AREA_Y2 - LIST_AREA_Y1)
+					* gc_zoom_factor_get())
+		    );
 
-  w = gtk_vscrollbar_new (GTK_LAYOUT(canvas_list_selector)->vadjustment);
+  w = gtk_vscrollbar_new (list_adj);
 
-  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-			 gnome_canvas_widget_get_type (),
-			 "widget", GTK_WIDGET(w),
-			 "x", (double) LIST_AREA_X2 - 5.0,
-			 "y", (double) LIST_AREA_Y1,
-			 "width", 30.0,
-			 "height", LIST_AREA_Y2 - LIST_AREA_Y1 - 20.0,
+  goo_canvas_widget_new (rootitem,
+			 w,
+			 LIST_AREA_X2 - 5.0,
+			 LIST_AREA_Y1,
+			 30.0,
+			 LIST_AREA_Y2 - LIST_AREA_Y1 - 20.0,
 			 NULL);
   gtk_widget_show (w);
-  gnome_canvas_set_center_scroll_region (GNOME_CANVAS (canvas_list_selector), FALSE);
 
   /* Set the scrollwheel event */
-  gtk_signal_connect(GTK_OBJECT(canvas_list_selector), "event",
-		     (GtkSignalFunc) item_event_scroll,
-		     GNOME_CANVAS(canvas_list_selector));
+  g_signal_connect (list_adj, "value_changed",
+		    (GtkSignalFunc) item_event_scroll,
+		    canvas_list_selector);
 
   /*
    * Create the image scrollbar
    * --------------------------
    */
-  canvas_image_selector     = GNOME_CANVAS(gnome_canvas_new ());
+  canvas_image_selector = goo_canvas_new ();
 
-  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-			 gnome_canvas_widget_get_type (),
-			 "widget", GTK_WIDGET(canvas_image_selector),
-			 "x", (double) DRAWING_AREA_X1,
-			 "y", (double) DRAWING_AREA_Y1,
-			 "width",  DRAWING_AREA_X2 - DRAWING_AREA_X1,
-			 "height", DRAWING_AREA_Y2 - DRAWING_AREA_Y1 - 35.0,
+  goo_canvas_widget_new (rootitem,
+			 canvas_image_selector,
+			 DRAWING_AREA_X1,
+			 DRAWING_AREA_Y1,
+			 DRAWING_AREA_X2 - DRAWING_AREA_X1,
+			 DRAWING_AREA_Y2 - DRAWING_AREA_Y1,
 			 NULL);
 
-  gtk_widget_show (GTK_WIDGET(canvas_image_selector));
+  gtk_widget_show (canvas_image_selector);
 
   /* Set the new canvas to the background color or it's white */
-  image_bg_item = gnome_canvas_item_new (gnome_canvas_root(canvas_image_selector),
-					gnome_canvas_rect_get_type (),
-					"x1", (double) 0,
-					"y1", (double) 0,
-					"x2", (double) DRAWING_AREA_X2 - DRAWING_AREA_X1,
-					"y2", (double) DRAWING_AREA_Y2 - DRAWING_AREA_Y1,
-					 "fill_color_rgba", gc_skin_get_color("gcompris/imageselectbg"),
-					NULL);
+  image_bg_item = \
+    goo_canvas_rect_new (goo_canvas_get_root_item(GOO_CANVAS(canvas_image_selector)),
+			 0,
+			 0,
+			 (DRAWING_AREA_X2 - DRAWING_AREA_X1)
+			 * gc_zoom_factor_get(),
+			 (DRAWING_AREA_Y2 - DRAWING_AREA_Y1)
+			 * gc_zoom_factor_get(),
+			 "fill-color-rgba",
+			 gc_skin_get_color("gcompris/imageselectbg_right"),
+			 "line-width", 0.0,
+			 NULL);
 
+  image_adj = \
+    GTK_ADJUSTMENT (gtk_adjustment_new (0.00, 0.00,
+					0.00,
+					10, IMAGE_HEIGHT,
+					(DRAWING_AREA_Y2 - DRAWING_AREA_Y1)
+					* gc_zoom_factor_get())
+		    );
 
-  w = gtk_vscrollbar_new (GTK_LAYOUT(canvas_image_selector)->vadjustment);
+  w = gtk_vscrollbar_new (image_adj);
 
-  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-			 gnome_canvas_widget_get_type (),
-			 "widget", GTK_WIDGET(w),
-			 "x", (double) DRAWING_AREA_X2 - 5.0,
-			 "y", (double) DRAWING_AREA_Y1,
-			 "width", 30.0,
-			 "height", DRAWING_AREA_Y2 - DRAWING_AREA_Y1 - 20.0,
+  goo_canvas_widget_new (rootitem,
+			 w,
+			 DRAWING_AREA_X2 - 5.0,
+			 DRAWING_AREA_Y1,
+			 30.0,
+			 DRAWING_AREA_Y2 - DRAWING_AREA_Y1 - 20.0,
 			 NULL);
   gtk_widget_show (w);
-  gnome_canvas_set_center_scroll_region (GNOME_CANVAS (canvas_image_selector), FALSE);
 
   /* Set the scrollwheel event */
-  gtk_signal_connect(GTK_OBJECT(canvas_image_selector), "event",
-		     (GtkSignalFunc) item_event_scroll,
-		     GNOME_CANVAS(canvas_image_selector));
+  g_signal_connect (image_adj, "value_changed",
+		    (GtkSignalFunc) item_event_scroll,
+		    canvas_image_selector);
 
   /*
    * DISPLAY IMAGES
    */
 
   /* Initial image position */
-  ix  = 0;
-  iy  = 0;
-  isy = 0;
+  isy = 0.0;
 
   /* I need  the following :
      -> if dataset is a file read it.
@@ -252,7 +257,7 @@ gc_selector_images_start (GcomprisBoard *gcomprisBoard, gchar *dataset,
   */
   dataseturl = \
     gc_file_find_absolute(dataset,
-				    NULL);
+			  NULL);
 
   /* if the file doesn't exist */
   if(g_file_test ((dataseturl), G_FILE_TEST_IS_DIR) )
@@ -295,37 +300,13 @@ gc_selector_images_start (GcomprisBoard *gcomprisBoard, gchar *dataset,
    * OK Button
    * ---------
    */
-  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap,
-				"x", (double) (BOARDWIDTH*0.5) - gdk_pixbuf_get_width(pixmap)/2,
-				"y", (double) y - gdk_pixbuf_get_height(pixmap) - 10,
-				NULL);
-
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) item_event_images_selector,
-		     "/ok/");
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gc_item_focus_event,
-		     NULL);
-
-  item2 = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				gnome_canvas_text_get_type (),
-				"text", _("OK"),
-				"font", gc_skin_font_title,
-				"x", (double)  BOARDWIDTH*0.5,
-				"y", (double)  y - gdk_pixbuf_get_height(pixmap) + 15,
-				"anchor", GTK_ANCHOR_CENTER,
-				"fill_color_rgba", gc_skin_color_text_button,
-				NULL);
-  gtk_signal_connect(GTK_OBJECT(item2), "event",
-		     (GtkSignalFunc) item_event_images_selector,
-		     "/ok/");
-  gtk_signal_connect(GTK_OBJECT(item2), "event",
-		     (GtkSignalFunc) gc_item_focus_event,
-		     item);
-  gdk_pixbuf_unref(pixmap);
-
+  gc_util_button_text_svg(rootitem,
+			  (BOARDWIDTH*0.5),
+			  BOARDHEIGHT - 32,
+			  "#BUTTON_TEXT",
+			  _("OK"),
+			  (GtkSignalFunc) item_event_images_selector,
+			  "/ok/");
 }
 
 /*
@@ -336,16 +317,15 @@ void gc_selector_images_stop ()
 {
   GcomprisBoard *gcomprisBoard = gc_board_get_current();
 
-  if(gcomprisBoard!=NULL && images_selector_displayed)
+  if(gcomprisBoard != NULL && images_selector_displayed)
     {
       gc_board_pause(FALSE);
     }
 
-  // Destroy the images_selector box
+  // Destroy the image_selector box
   if(rootitem!=NULL)
-    {
-      gtk_object_destroy(GTK_OBJECT(rootitem));
-    }
+    goo_canvas_item_remove(rootitem);
+
   rootitem = NULL;
   current_root_set = NULL;
 
@@ -361,67 +341,55 @@ void gc_selector_images_stop ()
 /*-------------------------------------------------------------------------------*/
 
 static void
-display_image(gchar *imagename, GnomeCanvasItem *root_item)
+display_image(gchar *imagename, GooCanvasItem *root_item)
 {
-
   GdkPixbuf *pixmap = NULL;
-  GnomeCanvasItem *item;
+  GooCanvasItem *item;
   double xratio, yratio;
   double iw, ih;
 
   if (imagename==NULL || !images_selector_displayed)
     return;
 
-  pixmap = gc_pixmap_load(imagename);
+  pixmap = gc_pixmap_load_or_null(imagename);
 
   /* Sad, the image is not found */
   if(!pixmap)
     return;
 
-  iw = IMAGE_WIDTH;
-  ih = IMAGE_HEIGHT;
+  iw = IMAGE_WIDTH * gc_zoom_factor_get();
+  ih = IMAGE_HEIGHT * gc_zoom_factor_get();
 
   /* Calc the max to resize width or height */
-  xratio = (double) (((double)gdk_pixbuf_get_width(pixmap))/iw);
-  yratio = (double) (((double)gdk_pixbuf_get_height(pixmap))/ih);
-  xratio = MAX(yratio,xratio);
+  xratio = (double) ((iw/(double)gdk_pixbuf_get_width(pixmap)));
+  yratio = (double) ((ih/(double)gdk_pixbuf_get_height(pixmap)));
+  xratio = MIN(yratio, xratio);
 
-  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(root_item),
-				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap,
-				"x", (double)ix,
-				"y", (double)iy,
-				"width", (double) gdk_pixbuf_get_width(pixmap)/xratio,
-				"height", (double) gdk_pixbuf_get_height(pixmap)/xratio,
-				"width_set", TRUE,
-				"height_set", TRUE,
-				NULL);
+  item = goo_canvas_image_new (root_item,
+			       pixmap,
+			       0,
+			       0,
+			       NULL);
+  goo_canvas_item_translate(item, ix, iy);
+  goo_canvas_item_scale(item, xratio, xratio);
   gdk_pixbuf_unref(pixmap);
 
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) item_event_images_selector,
-		     imagename);
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gc_item_focus_event,
-		     NULL);
+  g_signal_connect(item, "button_press_event",
+		   (GtkSignalFunc) item_event_images_selector,
+		   imagename);
+  gc_item_focus_init(item, NULL);
 
-  ix+=IMAGE_WIDTH + IMAGE_GAP;
-  if(ix>=DRAWING_AREA_X2-DRAWING_AREA_X1-IMAGE_GAP)
+  ix += iw + IMAGE_GAP;
+  if(ix >= (DRAWING_AREA_X2 - DRAWING_AREA_X1)
+     * gc_zoom_factor_get() - IMAGE_GAP)
     {
-      guint iy_calc;
-      ix=0;
-      iy+=IMAGE_HEIGHT + IMAGE_GAP;
-
-      /* Cannot use GINT_TO_POINTER with a constant calculation */
-      iy_calc = iy + IMAGE_HEIGHT + IMAGE_GAP;
-      g_object_set_data (G_OBJECT (root_item), "iy", GINT_TO_POINTER (iy_calc));
-
-      if(iy>=DRAWING_AREA_Y2-DRAWING_AREA_Y1) {
-	gnome_canvas_item_set(image_bg_item,
-			      "y2", (double) iy + IMAGE_HEIGHT + IMAGE_GAP,
-			      NULL);
-      }
+      ix = 0;
+      iy += ih + IMAGE_GAP;
     }
+
+  /* Cannot use GINT_TO_POINTER with a constant calculation */
+  guint iy_calc = iy + (ih + IMAGE_GAP)*2;
+  g_object_set_data (G_OBJECT (root_item), "iy", GINT_TO_POINTER (iy_calc));
 }
 
 /*
@@ -432,74 +400,74 @@ static void
 display_image_set(gchar *imagename, GSList *imagelist)
 {
   GdkPixbuf *pixmap = NULL;
-  GnomeCanvasItem *item;
-  GnomeCanvasItem *rootitem_set;
+  GooCanvasItem *item;
+  GooCanvasItem *rootitem_set;
   double xratio, yratio;
   double iw, ih;
 
-  if (imagename==NULL || !images_selector_displayed)
+  if (imagename == NULL || !images_selector_displayed)
     return;
 
-  pixmap = gc_pixmap_load(imagename);
+  pixmap = gc_pixmap_load_or_null(imagename);
+  if (!pixmap)
+    return;
 
-  iw = LIST_IMAGE_WIDTH;
-  ih = LIST_IMAGE_HEIGHT;
+  iw = LIST_IMAGE_WIDTH * gc_zoom_factor_get();
+  ih = LIST_IMAGE_HEIGHT * gc_zoom_factor_get();
 
   /* Calc the max to resize width or height */
-  xratio = (double) (((double)gdk_pixbuf_get_width(pixmap))/iw);
-  yratio = (double) (((double)gdk_pixbuf_get_height(pixmap))/ih);
-  xratio = MAX(yratio,xratio);
+  xratio = (double) ((iw/(double)gdk_pixbuf_get_width(pixmap)));
+  yratio = (double) ((ih/(double)gdk_pixbuf_get_height(pixmap)));
+  xratio = MIN(yratio, xratio);
 
-  item = gnome_canvas_item_new (gnome_canvas_root(canvas_list_selector),
-				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap,
-				"x", (double)5,
-				"y", (double)isy,
-				"width", (double) gdk_pixbuf_get_width(pixmap)/xratio,
-				"height", (double) gdk_pixbuf_get_height(pixmap)/xratio,
-				"width_set", TRUE,
-				"height_set", TRUE,
-				NULL);
+  item = goo_canvas_image_new (goo_canvas_get_root_item(GOO_CANVAS(canvas_list_selector)),
+			       pixmap,
+			       0,
+			       0,
+			       NULL);
+  goo_canvas_item_translate(item, 5, isy);
+  goo_canvas_item_scale(item, xratio, xratio);
   gdk_pixbuf_unref(pixmap);
   g_object_set_data (G_OBJECT (item), "imagelist", imagelist);
 
-  gtk_signal_connect(GTK_OBJECT(item), "event",
+  g_signal_connect(item, "button_press_event",
 		     (GtkSignalFunc) item_event_imageset_selector,
 		     imagename);
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gc_item_focus_event,
-		     NULL);
+  gc_item_focus_init(item, NULL);
 
-  isy+=LIST_IMAGE_HEIGHT + IMAGE_GAP;
+  isy += ih + IMAGE_GAP;
 
-  gnome_canvas_set_scroll_region (GNOME_CANVAS (canvas_list_selector), 0, 0,
-				  LIST_AREA_X2- LIST_AREA_X1,
-				  isy - IMAGE_GAP);
+  gdouble upper = MAX(isy + ih + IMAGE_GAP,
+		      (LIST_AREA_Y2 - LIST_AREA_Y1)
+		      * gc_zoom_factor_get());
 
-  if(isy>=LIST_AREA_Y2-LIST_AREA_Y1) {
-    gnome_canvas_item_set(list_bg_item,
-			  "y2", (double)isy + LIST_IMAGE_HEIGHT + IMAGE_GAP,
-			  NULL);
-  }
+  goo_canvas_set_bounds (GOO_CANVAS(canvas_list_selector),
+			 0, 0,
+			 (LIST_AREA_X2 - LIST_AREA_X1)
+			 * gc_zoom_factor_get(),
+			 upper);
+
+  g_object_set(list_bg_item,
+	       "height", upper,
+	       NULL);
+
+  g_object_set(list_adj,
+	       "upper", upper,
+	       NULL);
 
   /* Create a root item to put the image list in it */
   rootitem_set = \
-    gnome_canvas_item_new (gnome_canvas_root(canvas_image_selector),
-			   gnome_canvas_group_get_type (),
-			   "x", (double)0,
-			   "y", (double)0,
-			   NULL);
+    goo_canvas_group_new (goo_canvas_get_root_item(GOO_CANVAS(canvas_image_selector)),
+			  NULL);
 
   g_object_set_data (G_OBJECT (item), "rootitem", rootitem_set);
   g_object_set_data (G_OBJECT (item), "imageset_done", GINT_TO_POINTER (0));
-  g_signal_connect (item, "destroy",
-		    G_CALLBACK (free_stuff),
-		    imagelist);
-
+  g_object_set_data_full (G_OBJECT (item), "imagelist",
+			  imagelist, (GDestroyNotify)free_stuff );
 }
 
 static void
-free_stuff (GtkObject *obj, GSList *list)
+free_stuff (GSList *list)
 {
   while (g_slist_length(list) > 0) {
     g_free(g_slist_nth_data(list,0));
@@ -511,135 +479,115 @@ free_stuff (GtkObject *obj, GSList *list)
 
 /* Callback when an image set is selected */
 static gint
-item_event_imageset_selector(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
+item_event_imageset_selector(GooCanvasItem *item, GdkEvent *event,
+			     gpointer data)
 {
   GSList *image_list;
-  GnomeCanvasItem *rootitem_set;
+  GooCanvasItem *rootitem_set;
   guint imageset_done;
+  gdouble last_iy;
 
   if(display_in_progress)
     return TRUE;
 
-  switch (event->type)
+  display_in_progress = TRUE;
+
+  /* We must display the list of images for this set */
+  image_list = (GSList *)g_object_get_data (G_OBJECT (item), "imagelist");
+  g_return_val_if_fail (image_list != NULL, FALSE);
+
+  /* We must display the list of images for this set */
+  rootitem_set = (GooCanvasItem *)g_object_get_data (G_OBJECT (item),
+						     "rootitem");
+  g_return_val_if_fail (rootitem_set != NULL, FALSE);
+
+  imageset_done = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item),
+						      "imageset_done"));
+
+  /* Hide the previous image set if any */
+  if (current_root_set != NULL) {
+    g_object_set (current_root_set,
+		  "visibility", GOO_CANVAS_ITEM_INVISIBLE,
+		  NULL);
+  }
+  /* Not yet displayed set */
+  if(!imageset_done)
     {
-    case GDK_ENTER_NOTIFY:
-      break;
-    case GDK_LEAVE_NOTIFY:
-      break;
-    case GDK_BUTTON_PRESS:
-	{
-	  guint last_iy;
+      /* Initial image position */
+      ix = 0;
+      iy = 0;
 
-	  display_in_progress = TRUE;
-
-	  /* We must display the list of images for this set */
-	  image_list = (GSList *)g_object_get_data (G_OBJECT (item), "imagelist");
-	  g_return_val_if_fail (image_list != NULL, FALSE);
-
-	  /* We must display the list of images for this set */
-	  rootitem_set = (GnomeCanvasItem *)g_object_get_data (G_OBJECT (item), "rootitem");
-	  g_return_val_if_fail (rootitem_set != NULL, FALSE);
-
-	  imageset_done = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "imageset_done"));
-
-	  /* Hide the previous image set if any */
-	  if (current_root_set != NULL) {
-	    gnome_canvas_item_hide(current_root_set);
-	  }
-	  /* Not yet displayed this set */
-	  if(!imageset_done) {
-	    guint iy_calc;
-	    /* Cannot use GINT_TO_POINTER with a constant calculation */
-	    /* Set the initial iy value                               */
-	    iy_calc = IMAGE_HEIGHT + IMAGE_GAP;
-	    g_object_set_data (G_OBJECT (rootitem_set), "iy", GINT_TO_POINTER (iy_calc));
-
-	    g_slist_foreach (image_list, (GFunc) display_image, rootitem_set);
-	    g_object_set_data (G_OBJECT (item), "imageset_done", GINT_TO_POINTER (1));
-	  }
-
-	  /* Set the image scrollbar back to its max position */
-	  last_iy = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (rootitem_set), "iy"));
-	  gnome_canvas_set_scroll_region (GNOME_CANVAS (canvas_image_selector), 0, 0,
-					  DRAWING_AREA_X2- DRAWING_AREA_X1,
-					  last_iy - IMAGE_GAP);
-	  if(last_iy>=DRAWING_AREA_Y2-DRAWING_AREA_Y1) {
-	    gnome_canvas_item_set(image_bg_item,
-				  "y2", (double) last_iy + IMAGE_HEIGHT + IMAGE_GAP,
-				  NULL);
-	  }
-
-	  gnome_canvas_item_show(rootitem_set);
-	  current_root_set = rootitem_set;
-
-	  /* Back to the initial image position */
-	  ix  = 0;
-	  iy  = 0;
-
-	  display_in_progress = FALSE;
-	}
-    default:
-      break;
+      g_slist_foreach (image_list, (GFunc) display_image, rootitem_set);
+      g_object_set_data (G_OBJECT (item), "imageset_done", GINT_TO_POINTER (1));
     }
+
+  /* Set the image scrollbar back to its max position */
+  last_iy = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (rootitem_set), "iy"));
+  gdouble upper = MAX(last_iy,
+		      (DRAWING_AREA_Y2 - DRAWING_AREA_Y1)
+		      * gc_zoom_factor_get());
+
+  goo_canvas_set_bounds  (GOO_CANVAS(canvas_image_selector),
+			  0, 0,
+			  (DRAWING_AREA_X2 - DRAWING_AREA_X1)
+			  * gc_zoom_factor_get(),
+			  upper);
+
+  g_object_set(image_bg_item,
+	       "height", upper,
+	       NULL);
+
+  g_object_set(image_adj,
+  	       "upper", last_iy,
+  	       NULL);
+  gtk_adjustment_set_value(image_adj, 0);
+
+  g_object_set(rootitem_set,
+	       "visibility", GOO_CANVAS_ITEM_VISIBLE, NULL);
+
+  current_root_set = rootitem_set;
+
+  display_in_progress = FALSE;
+
   return FALSE;
 
 }
 
 /* Callback when an image is selected */
 static gint
-item_event_images_selector(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
+item_event_images_selector(GooCanvasItem *item,
+			   GooCanvasItem *target,
+			   GdkEvent *event,
+			   gchar *data)
 {
 
   if(display_in_progress)
     return TRUE;
 
-  switch (event->type)
+  if(!strcmp(data, "/ok/"))
     {
-    case GDK_ENTER_NOTIFY:
-      break;
-    case GDK_LEAVE_NOTIFY:
-      break;
-    case GDK_BUTTON_PRESS:
-      if(!strcmp((char *)data, "/ok/"))
-	{
-	  gc_selector_images_stop();
-	}
-      else
-	{
-	  if(imageSelectorCallBack!=NULL)
-	    imageSelectorCallBack(data);
-
-	  gc_selector_images_stop();
-	}
-    default:
-      break;
+      gc_selector_images_stop();
     }
+  else
+    {
+      if(imageSelectorCallBack!=NULL)
+	imageSelectorCallBack(data, current_user_context);
+
+      gc_selector_images_stop();
+    }
+
   return FALSE;
 
 }
 
 /* Callback when a scroll event happens */
-static gint
-item_event_scroll(GnomeCanvasItem *item, GdkEvent *event, GnomeCanvas *canvas)
+static void
+item_event_scroll(GtkAdjustment *adj, GooCanvas *canvas)
 {
-  int x, y;
   if(!rootitem)
-    return FALSE;
+    return;
 
-  switch (event->type)
-    {
-    case GDK_SCROLL:
-      gnome_canvas_get_scroll_offsets (canvas, &x, &y);
-      if ( event->scroll.direction == GDK_SCROLL_UP )
-	gnome_canvas_scroll_to (canvas, x, y - 20);
-      else if ( event->scroll.direction == GDK_SCROLL_DOWN )
-	gnome_canvas_scroll_to (canvas, x, y + 20);
-
-      break;
-    default:
-      break;
-    }
-  return FALSE;
+  goo_canvas_scroll_to (canvas, 0, adj->value);
 }
 
 /*
