@@ -31,4 +31,13 @@ void gc_score_start (ScoreStyleList style, guint x, guint y, guint max);
 void gc_score_end();
 void gc_score_set(guint value);
 
+typedef struct
+{
+  void (*start) (ScoreStyleList style, guint x, guint y, guint max);
+  void (*end) ();
+  void (*set) (guint value);
+} Score;
+
+void gc_score_register (Score *score);
+
 #endif
