@@ -1,6 +1,6 @@
 /* gcompris - skin.c
  *
- * Copyright (C) 2003 GCompris Developpement Team
+ * Copyright (C) 2003, 2008 GCompris Developpement Team
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -62,26 +62,22 @@ gc_skin_image_get(gchar *pixmapfile)
   gchar *filename;
 
   /* First, test if pixmapfile is in the current skin dir */
-  filename = g_strdup_printf("%s/skins/%s/%s",
-			     properties->package_data_dir,
-			     properties->skin, pixmapfile);
+  filename = g_strdup_printf("%s/%s/%s",
+			     properties->package_skin_dir,
+			     properties->skin,
+			     pixmapfile);
 
   if (g_file_test ((filename), G_FILE_TEST_EXISTS)) {
     g_free(filename);
 
-    filename = g_strdup_printf("skins/%s/%s", properties->skin, pixmapfile);
+    filename = g_strdup_printf("%s/%s", properties->skin, pixmapfile);
 
     return(filename);
   }
   g_free(filename);
 
-  /* Check it's on the server */
-  filename = gc_net_get_url_from_file("boards/skins/%s/%s", properties->skin, pixmapfile);
-  if(filename)
-    return(filename);
-
   /* Return the default skin dir */
-  filename = g_strdup_printf("skins/%s/%s", DEFAULT_SKIN, pixmapfile);
+  filename = g_strdup_printf("%s/%s", DEFAULT_SKIN, pixmapfile);
   return(filename);
 }
 
@@ -105,6 +101,48 @@ gc_skin_pixmap_load(char *pixmapfile)
   return (result_pixbuf);
 }
 
+/*
+ * Return the rsvg_handle of skin.svg from the current
+ * skin directory.
+ * If not found, try in the default skin directory
+ * If not found abort gcompris
+ * @WARNING: Do not free the returned handle, it is kept
+ *           cached internally.
+ */
+RsvgHandle *
+gc_skin_rsvg_get()
+{
+  /* Return value is cached, we don't support skin change on the fly */
+  static RsvgHandle *result_svg = NULL;
+
+  if (result_svg)
+    return result_svg;
+
+  result_svg = gc_skin_rsvg_load("skin.svg");
+
+  return (result_svg);
+}
+
+/*
+ * Load a pixmap from the current skin directory
+ * If not found, try in the default skin directory
+ * If not found abort gcompris
+ */
+RsvgHandle *
+gc_skin_rsvg_load(char *pixmapfile)
+{
+  gchar *filename;
+  RsvgHandle *result_svg;
+
+  filename = gc_skin_image_get(pixmapfile);
+
+  result_svg = gc_rsvg_load (filename);
+
+  g_free(filename);
+
+  return (result_svg);
+}
+
 /*
  * Utility function used when freeing the memory used by
  * a hashtable containing strings.
@@ -259,9 +297,9 @@ skin_xml_load (gchar* skin)
   g_return_if_fail(skin!=NULL);
 
   xmlfilename = \
-    gc_file_find_absolute("skins/%s/skin.xml",
-				    skin,
-				    NULL);
+    gc_file_find_absolute("%s/skin.xml",
+			  skin,
+			  NULL);
 
   /* if the file doesn't exist */
   if(!xmlfilename)
