@@ -25,6 +25,7 @@
 
 static GList *item_list = NULL;
 static GList *item2del_list = NULL;
+static guint actors_count = 0;
 
 static GcomprisBoard *gcomprisBoard = NULL;
 
@@ -288,7 +289,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 {
   GHashTable *config = gc_db_get_board_conf();
 
-  gc_locale_set(g_hash_table_lookup( config, "locale"));
+  gc_locale_change(g_hash_table_lookup( config, "locale"));
 
   gchar *up_init_str = g_hash_table_lookup( config, "uppercase_only");
 
@@ -514,6 +515,7 @@ static void gletters_destroy_item(GooCanvasItem *item)
   key = key_find_by_item(item);
 
   item_list = g_list_remove (item_list, item);
+  --actors_count;
 
   item2del_list = g_list_remove (item2del_list, item);
 
@@ -546,6 +548,8 @@ static void gletters_destroy_all_items()
 	gletters_destroy_item(item);
       }
 
+   actors_count= 0;
+
   /* Delete the letters_table */
   if(letters_table) {
     g_hash_table_destroy (letters_table);
@@ -564,7 +568,7 @@ static gint gletters_move_items (GtkWidget *widget, gpointer data)
   /* Destroy items that falls out of the canvas */
   gletters_destroy_items();
 
-  dummy_id = gtk_timeout_add (speed,
+  dummy_id = gtk_timeout_add (gc_timing (speed, actors_count),
 			      (GtkFunction) gletters_move_items, NULL);
 
   return(FALSE);
@@ -668,6 +672,7 @@ static GooCanvasItem *gletters_create_item(GooCanvasItem *parent)
   g_object_set_data (G_OBJECT(item), "utf8_key", letter);
 
   item_list = g_list_append (item_list, item);
+  ++actors_count;
 
   /* Add letter to hash table of all falling letters. */
   g_hash_table_insert (letters_table, lettersItem, item);
@@ -790,8 +795,6 @@ static void conf_ok(GHashTable *table)
   g_hash_table_foreach(table, save_table, NULL);
 
   if (gcomprisBoard){
-    gc_locale_reset();
-
     GHashTable *config;
 
     if (profile_conf)
