@@ -281,7 +281,7 @@ static gchar *wordnumberList[] =
 	N_("one"),
 	N_("two"),
 	N_("three"),
-	N_("for"),
+	N_("four"),
 	N_("five"),
 	N_("six"),
 	N_("seven"),
@@ -651,7 +651,7 @@ void get_random_token(int token_type, gint *returned_type, gchar **string, gchar
       {
       result = g_malloc0(2*sizeof(gunichar));
       g_utf8_strncpy(result, g_utf8_offset_to_pointer (numbers,k),1);
-      second = g_strdup(wordnumberList[k]);
+      second = g_strdup(gettext(wordnumberList[k]));
       break;
       }
     default:
@@ -891,7 +891,8 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 	  /* initial state to restore */
 	  sound_policy = gc_sound_policy_get();
 
-	  gc_sound_policy_set(PLAY_AND_INTERRUPT);
+	  // Will set the PLAY_AND_INTERRUPT policy on first
+	  // user click so that intro sounds is not
 
 	  gc_set_background(goo_canvas_get_root_item(gcomprisBoard->canvas),
 			    "memory/gcompris_band.svg");
@@ -1657,6 +1658,9 @@ static gboolean item_event (GooCanvasItem  *item,
   if(!gcomprisBoard)
     return FALSE;
 
+  if (currentUiMode == UIMODE_SOUND)
+    gc_sound_policy_set(PLAY_AND_INTERRUPT);
+
   if (event->type != GDK_BUTTON_PRESS ||
       event->button != 1)
     return FALSE;
@@ -1757,7 +1761,6 @@ compare_card (gconstpointer a,
 {
   MemoryItem *card1 = (MemoryItem *)a;
   MemoryItem *card2 = (MemoryItem *)b;
-
   if (card1->type & (TYPE_ADD|TYPE_MINUS|TYPE_MULT|TYPE_DIV|TYPE_ENUMERATE|TYPE_ENUMERATE_IMAGE|TYPE_WORDNUMBER)){
     if ((!card1->second_value) && ( card2->second_value)){
       return strcmp(card1->data,card2->second_value);
