@@ -169,7 +169,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 {
   GHashTable *config = gc_db_get_board_conf();
 
-  gc_locale_set(g_hash_table_lookup( config, "locale"));
+  gc_locale_change(g_hash_table_lookup( config, "locale"));
 
   g_hash_table_destroy(config);
 
@@ -453,7 +453,7 @@ reading_create_item(GooCanvasItem *parent)
 
   if(word==NULL)
   {
-  	gc_dialog(_("We skip this level because there are not enough word in the list!"),
+  	gc_dialog(_("We skip this level because there are not enough words in the list!"),
 		(DialogBoxCallBack)reading_next_level);
 	gcomprisBoard->level++;
 	if(gcomprisBoard->level>gcomprisBoard->maxlevel)
@@ -656,7 +656,7 @@ ask_yes_no()
 
   item2 =
     goo_canvas_text_new (boardRootItem,
-			 ("Yes, I saw it"),
+			 _("Yes, I saw it"),
 			 x_offset,
 			 y_offset,
 			 -1,
@@ -842,8 +842,6 @@ static void conf_ok(GHashTable *table)
   g_hash_table_foreach(table, (GHFunc) save_table, NULL);
 
   if (gcomprisBoard){
-    gc_locale_reset();
-
     GHashTable *config;
 
     if (profile_conf)
